@@ -31,6 +31,7 @@
 #include "mapreader.h"
 
 #include "compression.h"
+#include "gidmapper.h"
 #include "objectgroup.h"
 #include "map.h"
 #include "mapobject.h"
@@ -42,7 +43,6 @@
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
-#include <QMap>
 #include <QXmlStreamReader>
 
 using namespace Tiled;
@@ -70,9 +70,7 @@ public:
     QString errorString() const;
 
 private:
-    bool readNextStartElement();
     void readUnknownElement();
-    void skipCurrentElement();
 
     Map *readMap();
 
@@ -83,20 +81,19 @@ private:
     TileLayer *readLayer();
     void readLayerData(TileLayer *tileLayer);
     void decodeBinaryLayerData(TileLayer *tileLayer,
-                               const QString &text,
+                               const QStringRef &text,
                                const QStringRef &compression);
     void decodeCSVLayerData(TileLayer *tileLayer, const QString &text);
 
     /**
-     * Returns the tile for the given global tile ID. When an error occurs,
-     * \a ok is set to false and an error is raised.
+     * Returns the cell for the given global tile ID. Errors are raised with
+     * the QXmlStreamReader.
      *
-     * @param gid the global tile ID, must be at least 0
-     * @param ok  returns whether the conversion went ok
-     * @return the tile associated with the given global tile ID, or 0 if
-     *         not found
+     * @param gid the global tile ID
+     * @return the cell data associated with the given global tile ID, or an
+     *         empty cell if not found
      */
-    Tile *tileForGid(int gid, bool &ok);
+    Cell cellForGid(uint gid);
 
     ObjectGroup *readObjectGroup();
     MapObject *readObject();
@@ -109,7 +106,7 @@ private:
     QString mError;
     QString mPath;
     Map *mMap;
-    QMap<int, Tileset*> mGidsToTileset;
+    GidMapper mGidMapper;
     bool mReadingExternalTileset;
 
     QXmlStreamReader xml;
@@ -126,13 +123,13 @@ Map *MapReaderPrivate::readMap(QIODevice *device, const QString &path)
 
     xml.setDevice(device);
 
-    if (readNextStartElement() && xml.name() == "map") {
+    if (xml.readNextStartElement() && xml.name() == "map") {
         map = readMap();
     } else {
         xml.raiseError(tr("Not a map file."));
     }
 
-    mGidsToTileset.clear();
+    mGidMapper.clear();
     return map;
 }
 
@@ -145,7 +142,7 @@ Tileset *MapReaderPrivate::readTileset(QIODevice *device, const QString &path)
 
     xml.setDevice(device);
 
-    if (readNextStartElement() && xml.name() == "tileset")
+    if (xml.readNextStartElement() && xml.name() == "tileset")
         tileset = readTileset();
     else
         xml.raiseError(tr("Not a tileset file."));
@@ -179,27 +176,10 @@ bool MapReaderPrivate::openFile(QFile *file)
     return true;
 }
 
-bool MapReaderPrivate::readNextStartElement()
-{
-    while (xml.readNext() != QXmlStreamReader::Invalid) {
-        if (xml.isEndElement())
-            return false;
-        else if (xml.isStartElement())
-            return true;
-    }
-    return false;
-}
-
 void MapReaderPrivate::readUnknownElement()
 {
     qDebug() << "Unknown element (fixme):" << xml.name();
-    skipCurrentElement();
-}
-
-void MapReaderPrivate::skipCurrentElement()
-{
-    while (readNextStartElement())
-        skipCurrentElement();
+    xml.skipCurrentElement();
 }
 
 static Map::Orientation orientationFromString(const QStringRef &string)
@@ -239,7 +219,7 @@ Map *MapReaderPrivate::readMap()
 
     mMap = new Map(orientation, mapWidth, mapHeight, tileWidth, tileHeight);
 
-    while (readNextStartElement()) {
+    while (xml.readNextStartElement()) {
         if (xml.name() == "properties")
             mMap->mergeProperties(readProperties());
         else if (xml.name() == "tileset")
@@ -254,11 +234,11 @@ Map *MapReaderPrivate::readMap()
 
     // Clean up in case of error
     if (xml.hasError()) {
+        // The tilesets are not owned by the map
+        qDeleteAll(mMap->tilesets());
+
         delete mMap;
         mMap = 0;
-
-        // The tilesets are not owned by the map
-        qDeleteAll(mGidsToTileset.values());
     }
 
     return mMap;
@@ -270,8 +250,8 @@ Tileset *MapReaderPrivate::readTileset()
 
     const QXmlStreamAttributes atts = xml.attributes();
     const QString source = atts.value(QLatin1String("source")).toString();
-    const int firstGid =
-            atts.value(QLatin1String("firstgid")).toString().toInt();
+    const uint firstGid =
+            atts.value(QLatin1String("firstgid")).toString().toUInt();
 
     Tileset *tileset = 0;
 
@@ -288,14 +268,14 @@ Tileset *MapReaderPrivate::readTileset()
                 atts.value(QLatin1String("margin")).toString().toInt();
 
         if (tileWidth <= 0 || tileHeight <= 0
-            || (firstGid <= 0 && !mReadingExternalTileset)) {
+            || (firstGid == 0 && !mReadingExternalTileset)) {
             xml.raiseError(tr("Invalid tileset parameters for tileset"
                               " '%1'").arg(name));
         } else {
             tileset = new Tileset(name, tileWidth, tileHeight,
                                   tileSpacing, margin);
 
-            while (readNextStartElement()) {
+            while (xml.readNextStartElement()) {
                 if (xml.name() == "tile")
                     readTilesetTile(tileset);
                 else if (xml.name() == "image")
@@ -314,11 +294,11 @@ Tileset *MapReaderPrivate::readTileset()
                            .arg(absoluteSource, error));
         }
 
-        skipCurrentElement();
+        xml.skipCurrentElement();
     }
 
     if (tileset && !mReadingExternalTileset)
-        mGidsToTileset.insert(firstGid, tileset);
+        mGidMapper.insert(firstGid, tileset);
 
     return tileset;
 }
@@ -337,7 +317,7 @@ void MapReaderPrivate::readTilesetTile(Tileset *tileset)
 
     // TODO: Add support for individual tiles (then it needs to be added here)
 
-    while (readNextStartElement()) {
+    while (xml.readNextStartElement()) {
         if (xml.name() == "properties") {
             Tile *tile = tileset->tileAt(id);
             tile->mergeProperties(readProperties());
@@ -367,7 +347,7 @@ void MapReaderPrivate::readTilesetImage(Tileset *tileset)
     if (!tileset->loadFromImage(tilesetImage, source))
         xml.raiseError(tr("Error loading tileset image:\n'%1'").arg(source));
 
-    skipCurrentElement();
+    xml.skipCurrentElement();
 }
 
 static void readLayerAttributes(Layer *layer,
@@ -400,7 +380,7 @@ TileLayer *MapReaderPrivate::readLayer()
     TileLayer *tileLayer = new TileLayer(name, x, y, width, height);
     readLayerAttributes(tileLayer, atts);
 
-    while (readNextStartElement()) {
+    while (xml.readNextStartElement()) {
         if (xml.name() == "properties")
             tileLayer->mergeProperties(readProperties());
         else if (xml.name() == "data")
@@ -434,13 +414,8 @@ void MapReaderPrivate::readLayerData(TileLayer *tileLayer)
                 }
 
                 const QXmlStreamAttributes atts = xml.attributes();
-                int gid = atts.value(QLatin1String("gid")).toString().toInt();
-                bool ok;
-                Tile *tile = tileForGid(gid, ok);
-                if (ok)
-                    tileLayer->setTile(x, y, tile);
-                else
-                    xml.raiseError(tr("Invalid tile: %1").arg(gid));
+                uint gid = atts.value(QLatin1String("gid")).toString().toUInt();
+                tileLayer->setCell(x, y, cellForGid(gid));
 
                 x++;
                 if (x >= tileLayer->width()) {
@@ -448,14 +423,14 @@ void MapReaderPrivate::readLayerData(TileLayer *tileLayer)
                     y++;
                 }
 
-                skipCurrentElement();
+                xml.skipCurrentElement();
             } else {
                 readUnknownElement();
             }
         } else if (xml.isCharacters() && !xml.isWhitespace()) {
             if (encoding == QLatin1String("base64")) {
                 decodeBinaryLayerData(tileLayer,
-                                      xml.text().toString(),
+                                      xml.text(),
                                       compression);
             } else if (encoding == QLatin1String("csv")) {
                 decodeCSVLayerData(tileLayer, xml.text().toString());
@@ -469,10 +444,16 @@ void MapReaderPrivate::readLayerData(TileLayer *tileLayer)
 }
 
 void MapReaderPrivate::decodeBinaryLayerData(TileLayer *tileLayer,
-                                      const QString &text,
-                                      const QStringRef &compression)
+                                             const QStringRef &text,
+                                             const QStringRef &compression)
 {
-    QByteArray tileData = QByteArray::fromBase64(text.toLatin1());
+#if QT_VERSION < 0x040800
+    const QString textData = QString::fromRawData(text.unicode(), text.size());
+    const QByteArray latin1Text = textData.toLatin1();
+#else
+    const QByteArray latin1Text = text.toLatin1();
+#endif
+    QByteArray tileData = QByteArray::fromBase64(latin1Text);
     const int size = (tileLayer->width() * tileLayer->height()) * 4;
 
     if (compression == QLatin1String("zlib")
@@ -496,19 +477,12 @@ void MapReaderPrivate::decodeBinaryLayerData(TileLayer *tileLayer,
     int y = 0;
 
     for (int i = 0; i < size - 3; i += 4) {
-        const int gid = data[i] |
-                        data[i + 1] << 8 |
-                        data[i + 2] << 16 |
-                        data[i + 3] << 24;
+        const uint gid = data[i] |
+                         data[i + 1] << 8 |
+                         data[i + 2] << 16 |
+                         data[i + 3] << 24;
 
-        bool ok;
-        Tile *tile = tileForGid(gid, ok);
-        if (ok)
-            tileLayer->setTile(x, y, tile);
-        else {
-            xml.raiseError(tr("Invalid tile: %1").arg(gid));
-            return;
-        }
+        tileLayer->setCell(x, y, cellForGid(gid));
 
         x++;
         if (x == tileLayer->width()) {
@@ -532,47 +506,29 @@ void MapReaderPrivate::decodeCSVLayerData(TileLayer *tileLayer, const QString &t
     for (int y = 0; y < tileLayer->height(); y++) {
         for (int x = 0; x < tileLayer->width(); x++) {
             bool conversionOk;
-            const int gid = tiles.at(y * tileLayer->width() + x)
-                            .toInt(&conversionOk);
+            const uint gid = tiles.at(y * tileLayer->width() + x)
+                    .toUInt(&conversionOk);
             if (!conversionOk) {
                 xml.raiseError(
                         tr("Unable to parse tile at (%1,%2) on layer '%3'")
                                .arg(x + 1).arg(y + 1).arg(tileLayer->name()));
                 return;
             }
-            bool gidOk;
-            Tile *tile = tileForGid(gid, gidOk);
-            if (gidOk)
-                tileLayer->setTile(x, y, tile);
-            else {
-                xml.raiseError(tr("Invalid tile: %1").arg(gid));
-            }
+            tileLayer->setCell(x, y, cellForGid(gid));
         }
     }
 }
 
-Tile *MapReaderPrivate::tileForGid(int gid, bool &ok)
+Cell MapReaderPrivate::cellForGid(uint gid)
 {
-    Tile *result = 0;
+    bool ok;
+    const Cell result = mGidMapper.gidToCell(gid, ok);
 
-    if (gid < 0) {
-        xml.raiseError(tr("Invalid global tile id (less than 0): %1")
-                       .arg(gid));
-        ok = false;
-    } else if (gid == 0) {
-        ok = true;
-    } else if (mGidsToTileset.isEmpty()) {
-        xml.raiseError(tr("Tile used but no tilesets specified"));
-        ok = false;
-    } else {
-        // Find the tileset containing this tile
-        QMap<int, Tileset*>::const_iterator i = mGidsToTileset.upperBound(gid);
-        --i; // Navigate one tileset back since upper bound finds the next
-        const int tileId = gid - i.key();
-        const Tileset *tileset = i.value();
-
-        result = tileset ? tileset->tileAt(tileId) : 0;
-        ok = true;
+    if (!ok) {
+        if (mGidMapper.isEmpty())
+            xml.raiseError(tr("Tile used but no tilesets specified"));
+        else
+            xml.raiseError(tr("Invalid tile: %1").arg(gid));
     }
 
     return result;
@@ -596,7 +552,7 @@ ObjectGroup *MapReaderPrivate::readObjectGroup()
     if (!color.isEmpty())
         objectGroup->setColor(color);
 
-    while (readNextStartElement()) {
+    while (xml.readNextStartElement()) {
         if (xml.name() == "object")
             objectGroup->addObject(readObject());
         else if (xml.name() == "properties")
@@ -614,7 +570,7 @@ MapObject *MapReaderPrivate::readObject()
 
     const QXmlStreamAttributes atts = xml.attributes();
     const QString name = atts.value(QLatin1String("name")).toString();
-    const int gid = atts.value(QLatin1String("gid")).toString().toInt();
+    const uint gid = atts.value(QLatin1String("gid")).toString().toUInt();
     const int x = atts.value(QLatin1String("x")).toString().toInt();
     const int y = atts.value(QLatin1String("y")).toString().toInt();
     const int width = atts.value(QLatin1String("width")).toString().toInt();
@@ -643,16 +599,11 @@ MapObject *MapReaderPrivate::readObject()
     MapObject *object = new MapObject(name, type, xF, yF, widthF, heightF);
 
     if (gid) {
-        bool ok;
-        Tile *tile = tileForGid(gid, ok);
-        if (ok) {
-            object->setTile(tile);
-        } else {
-            xml.raiseError(tr("Invalid tile: %1").arg(gid));
-        }
+        const Cell cell = cellForGid(gid);
+        object->setTile(cell.tile);
     }
 
-    while (readNextStartElement()) {
+    while (xml.readNextStartElement()) {
         if (xml.name() == "properties")
             object->mergeProperties(readProperties());
         else
@@ -668,7 +619,7 @@ Properties MapReaderPrivate::readProperties()
 
     Properties properties;
 
-    while (readNextStartElement()) {
+    while (xml.readNextStartElement()) {
         if (xml.name() == "property")
             readProperty(&properties);
         else
