@@ -87,6 +87,8 @@ LayerDock::LayerDock(QWidget *parent):
     buttonContainer->addAction(handler->actionMoveLayerDown());
     buttonContainer->addAction(handler->actionDuplicateLayer());
     buttonContainer->addAction(handler->actionRemoveLayer());
+    buttonContainer->addSeparator();
+    buttonContainer->addAction(handler->actionToggleOtherLayers());
 
     layout->addLayout(opacityLayout);
     layout->addWidget(mLayerView);
@@ -116,7 +118,7 @@ void LayerDock::setMapDocument(MapDocument *mapDocument)
     mMapDocument = mapDocument;
 
     if (mMapDocument) {
-        connect(mMapDocument, SIGNAL(currentLayerChanged(int)),
+        connect(mMapDocument, SIGNAL(currentLayerIndexChanged(int)),
                 this, SLOT(updateOpacitySlider()));
     }
 
@@ -139,14 +141,13 @@ void LayerDock::changeEvent(QEvent *e)
 void LayerDock::updateOpacitySlider()
 {
     const bool enabled = mMapDocument &&
-                         mMapDocument->currentLayer() != -1;
+                         mMapDocument->currentLayerIndex() != -1;
 
     mOpacitySlider->setEnabled(enabled);
     mOpacityLabel->setEnabled(enabled);
 
     if (enabled) {
-        int layerIndex = mMapDocument->currentLayer();
-        qreal opacity = mMapDocument->map()->layerAt(layerIndex)->opacity();
+        qreal opacity = mMapDocument->currentLayer()->opacity();
         mOpacitySlider->setValue((int) (opacity * 100));
     } else {
         mOpacitySlider->setValue(100);
@@ -158,7 +159,7 @@ void LayerDock::setLayerOpacity(int opacity)
     if (!mMapDocument)
         return;
 
-    const int layerIndex = mMapDocument->currentLayer();
+    const int layerIndex = mMapDocument->currentLayerIndex();
     if (layerIndex == -1)
         return;
 
@@ -209,8 +210,8 @@ void LayerView::setMapDocument(MapDocument *mapDocument)
     if (mMapDocument) {
         setModel(mMapDocument->layerModel());
 
-        connect(mMapDocument, SIGNAL(currentLayerChanged(int)),
-                this, SLOT(currentLayerChanged(int)));
+        connect(mMapDocument, SIGNAL(currentLayerIndexChanged(int)),
+                this, SLOT(currentLayerIndexChanged(int)));
         connect(mMapDocument, SIGNAL(editLayerNameRequested()),
                 this, SLOT(editLayerName()));
 
@@ -218,7 +219,7 @@ void LayerView::setMapDocument(MapDocument *mapDocument)
         connect(s, SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
                 this, SLOT(currentRowChanged(QModelIndex)));
 
-        currentLayerChanged(mMapDocument->currentLayer());
+        currentLayerIndexChanged(mMapDocument->currentLayerIndex());
     } else {
         setModel(0);
     }
@@ -227,10 +228,10 @@ void LayerView::setMapDocument(MapDocument *mapDocument)
 void LayerView::currentRowChanged(const QModelIndex &index)
 {
     const int layer = mMapDocument->layerModel()->toLayerIndex(index);
-    mMapDocument->setCurrentLayer(layer);
+    mMapDocument->setCurrentLayerIndex(layer);
 }
 
-void LayerView::currentLayerChanged(int index)
+void LayerView::currentLayerIndexChanged(int index)
 {
     if (index > -1) {
         const LayerModel *layerModel = mMapDocument->layerModel();
@@ -247,7 +248,8 @@ void LayerView::editLayerName()
         return;
 
     const LayerModel *layerModel = mMapDocument->layerModel();
-    const int row = layerModel->layerIndexToRow(mMapDocument->currentLayer());
+    const int currentLayerIndex = mMapDocument->currentLayerIndex();
+    const int row = layerModel->layerIndexToRow(currentLayerIndex);
     edit(layerModel->index(row));
 }
 
@@ -268,11 +270,14 @@ void LayerView::contextMenuEvent(QContextMenuEvent *event)
 
     if (layerIndex >= 0) {
         menu.addAction(handler->actionDuplicateLayer());
+        menu.addAction(handler->actionMergeLayerDown());
         menu.addAction(handler->actionRemoveLayer());
         menu.addSeparator();
         menu.addAction(handler->actionMoveLayerUp());
         menu.addAction(handler->actionMoveLayerDown());
         menu.addSeparator();
+        menu.addAction(handler->actionToggleOtherLayers());
+        menu.addSeparator();
         menu.addAction(handler->actionLayerProperties());
     }
 
