@@ -28,6 +28,7 @@
 #include "ui_mainwindow.h"
 
 #include "aboutdialog.h"
+#include "addremovemapobject.h"
 #include "automap.h"
 #include "addremovetileset.h"
 #include "clipboardmanager.h"
@@ -44,6 +45,8 @@
 #include "map.h"
 #include "mapdocument.h"
 #include "mapdocumentactionhandler.h"
+#include "mapobject.h"
+#include "maprenderer.h"
 #include "mapscene.h"
 #include "newmapdialog.h"
 #include "newtilesetdialog.h"
@@ -51,9 +54,11 @@
 #include "propertiesdialog.h"
 #include "resizedialog.h"
 #include "objectselectiontool.h"
+#include "objectgroup.h"
 #include "offsetmapdialog.h"
 #include "preferences.h"
 #include "preferencesdialog.h"
+#include "quickstampmanager.h"
 #include "saveasimagedialog.h"
 #include "selectiontool.h"
 #include "stampbrush.h"
@@ -96,7 +101,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     , mZoomLabel(new QLabel)
     , mStatusInfoLabel(new QLabel)
     , mClipboardManager(new ClipboardManager(this))
-    , mDocumentManager(new DocumentManager(this))
+    , mDocumentManager(DocumentManager::instance())
 {
     mUi->setupUi(this);
     setCentralWidget(mDocumentManager->widget());
@@ -128,11 +133,9 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     QUndoGroup *undoGroup = mDocumentManager->undoGroup();
     QAction *undoAction = undoGroup->createUndoAction(this, tr("Undo"));
     QAction *redoAction = undoGroup->createRedoAction(this, tr("Redo"));
-#if QT_VERSION >= 0x040600
     mUi->mainToolBar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
     mUi->actionNew->setPriority(QAction::LowPriority);
     redoAction->setPriority(QAction::LowPriority);
-#endif
     redoAction->setIcon(redoIcon);
     undoAction->setIcon(undoIcon);
     redoAction->setIconText(tr("Redo"));
@@ -153,9 +156,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     mUi->actionSave->setShortcuts(QKeySequence::Save);
     mUi->actionSaveAs->setShortcuts(QKeySequence::SaveAs);
     mUi->actionClose->setShortcuts(QKeySequence::Close);
-#if QT_VERSION >= 0x040600
     mUi->actionQuit->setShortcuts(QKeySequence::Quit);
-#endif
     mUi->actionCut->setShortcuts(QKeySequence::Cut);
     mUi->actionCopy->setShortcuts(QKeySequence::Copy);
     mUi->actionPaste->setShortcuts(QKeySequence::Paste);
@@ -187,18 +188,26 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
 
     mUi->mainToolBar->addSeparator();
 
-    mCommandButton = new CommandButton(this, mDocumentManager);
+    mCommandButton = new CommandButton(this);
     mUi->mainToolBar->addWidget(mCommandButton);
 
+    mUi->menuMap->insertAction(mUi->actionOffsetMap,
+                               mActionHandler->actionCropToSelection());
+
     mLayerMenu = new QMenu(tr("&Layer"), this);
     mLayerMenu->addAction(mActionHandler->actionAddTileLayer());
     mLayerMenu->addAction(mActionHandler->actionAddObjectGroup());
     mLayerMenu->addAction(mActionHandler->actionDuplicateLayer());
+    mLayerMenu->addAction(mActionHandler->actionMergeLayerDown());
     mLayerMenu->addAction(mActionHandler->actionRemoveLayer());
     mLayerMenu->addSeparator();
+    mLayerMenu->addAction(mActionHandler->actionSelectPreviousLayer());
+    mLayerMenu->addAction(mActionHandler->actionSelectNextLayer());
     mLayerMenu->addAction(mActionHandler->actionMoveLayerUp());
     mLayerMenu->addAction(mActionHandler->actionMoveLayerDown());
     mLayerMenu->addSeparator();
+    mLayerMenu->addAction(mActionHandler->actionToggleOtherLayers());
+    mLayerMenu->addSeparator();
     mLayerMenu->addAction(mActionHandler->actionLayerProperties());
 
     menuBar()->insertMenu(mUi->menuHelp->menuAction(), mLayerMenu);
@@ -244,6 +253,9 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     connect(mUi->actionAbout, SIGNAL(triggered()), SLOT(aboutTiled()));
     connect(mUi->actionAboutQt, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
 
+    connect(mTilesetDock, SIGNAL(tilesetsDropped(QStringList)),
+            SLOT(newTilesets(QStringList)));
+
     // Add recent file actions to the recent files menu
     for (int i = 0; i < MaxRecentFiles; ++i)
     {
@@ -327,6 +339,9 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     connect(switchToRightDocument, SIGNAL(activated()),
             mDocumentManager, SLOT(switchToRightDocument()));
 
+    new QShortcut(tr("X"), this, SLOT(flipStampHorizontally()));
+    new QShortcut(tr("Y"), this, SLOT(flipStampVertically()));
+
     updateActions();
     readSettings();
     setupQuickStamps();
@@ -334,12 +349,13 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
 
 MainWindow::~MainWindow()
 {
-    cleanQuickStamps();
     mDocumentManager->closeAllDocuments();
 
     AutomaticMappingManager::deleteInstance();
+    QuickStampManager::deleteInstance();
     ToolManager::deleteInstance();
     TilesetManager::deleteInstance();
+    DocumentManager::deleteInstance();
     Preferences::deleteInstance();
     LanguageManager::deleteInstance();
     PluginManager::deleteInstance();
@@ -379,30 +395,31 @@ void MainWindow::changeEvent(QEvent *event)
     }
 }
 
+void MainWindow::keyPressEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Space && !event->isAutoRepeat())
+        if (MapView *mapView = mDocumentManager->currentMapView())
+            mapView->setHandScrolling(true);
+}
+
+void MainWindow::keyReleaseEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Space && !event->isAutoRepeat())
+        if (MapView *mapView = mDocumentManager->currentMapView())
+            mapView->setHandScrolling(false);
+}
+
 void MainWindow::dragEnterEvent(QDragEnterEvent *e)
 {
     const QList<QUrl> urls = e->mimeData()->urls();
-    if (urls.size() == 1 && !urls.at(0).toLocalFile().isEmpty())
+    if (!urls.isEmpty() && !urls.at(0).toLocalFile().isEmpty())
         e->accept();
 }
 
 void MainWindow::dropEvent(QDropEvent *e)
 {
-    const QString file = e->mimeData()->urls().at(0).toLocalFile();
-    const QString extension = QFileInfo(file).suffix();
-
-    // Treat file as a tileset if it is an image. Use the extension here because
-    // QImageReader::imageFormat() treats tmx files as svg
-    const QList<QByteArray> formats = QImageReader::supportedImageFormats();
-    foreach (const QByteArray &format, formats) {
-        if (extension.compare(QString::fromLatin1(format), Qt::CaseInsensitive) == 0) {
-            newTileset(file);
-            return;
-        }
-    }
-
-    // Treat file as a map otherwise
-    openFile(file);
+    foreach (const QUrl &url, e->mimeData()->urls())
+        openFile(url.toLocalFile());
 }
 
 void MainWindow::newMap()
@@ -467,24 +484,33 @@ bool MainWindow::openFile(const QString &fileName)
 
 void MainWindow::openLastFiles()
 {
-    const QStringList files = recentFiles();
-
     mSettings.beginGroup(QLatin1String("recentFiles"));
 
-    int openCount = mSettings.value(QLatin1String("recentOpenedFiles"), 1).toInt();
+    QStringList lastOpenFiles = mSettings.value(
+                QLatin1String("lastOpenFiles")).toStringList();
+    QVariant openCountVariant = mSettings.value(
+                QLatin1String("recentOpenedFiles"));
+
+    // Backwards compatibility mode
+    if (openCountVariant.isValid()) {
+        const QStringList recentFiles = mSettings.value(
+                    QLatin1String("fileNames")).toStringList();
+        int openCount = qMin(openCountVariant.toInt(), recentFiles.size());
+        for (; openCount; --openCount)
+            lastOpenFiles.append(recentFiles.at(openCount - 1));
+        mSettings.remove(QLatin1String("recentOpenedFiles"));
+    }
 
     QStringList mapScales = mSettings.value(
-                            QLatin1String("mapScale")).toStringList();
+                QLatin1String("mapScale")).toStringList();
     QStringList scrollX = mSettings.value(
-                          QLatin1String("scrollX")).toStringList();
+                QLatin1String("scrollX")).toStringList();
     QStringList scrollY = mSettings.value(
-                          QLatin1String("scrollY")).toStringList();
+                QLatin1String("scrollY")).toStringList();
     QStringList selectedLayer = mSettings.value(
-                                QLatin1String("selectedLayer")).toStringList();
+                QLatin1String("selectedLayer")).toStringList();
 
-    for (int i = 0; i < openCount; i++) {
-        if (!(i < files.size()))
-            break;
+    for (int i = 0; i < lastOpenFiles.size(); i++) {
         if (!(i < mapScales.size()))
             continue;
         if (!(i < scrollX.size()))
@@ -494,7 +520,7 @@ void MainWindow::openLastFiles()
         if (!(i < selectedLayer.size()))
             continue;
 
-        if (openFile(files.at(i))) {
+        if (openFile(lastOpenFiles.at(i))) {
             MapView *mapView = mDocumentManager->currentMapView();
 
             // Restore camera to the previous position
@@ -509,7 +535,7 @@ void MainWindow::openLastFiles()
 
             int layer = selectedLayer.at(i).toInt();
             if (layer > 0 && layer < mMapDocument->map()->layerCount())
-                mMapDocument->setCurrentLayer(layer);
+                mMapDocument->setCurrentLayerIndex(layer);
         }
     }
     QString lastActiveDocument =
@@ -562,16 +588,12 @@ bool MainWindow::saveFile(const QString &fileName)
     if (!mMapDocument)
         return false;
 
-    TmxMapWriter mapWriter;
-
-    if (!mapWriter.write(mMapDocument->map(), fileName)) {
-        QMessageBox::critical(this, tr("Error Saving Map"),
-                              mapWriter.errorString());
+    QString error;
+    if (!mMapDocument->save(fileName, &error)) {
+        QMessageBox::critical(this, tr("Error Saving Map"), error);
         return false;
     }
 
-    mMapDocument->undoStack()->setClean();
-    mMapDocument->setFileName(fileName);
     setRecentFile(fileName);
     return true;
 }
@@ -731,26 +753,28 @@ void MainWindow::cut()
     if (!mMapDocument)
         return;
 
-    int currentLayer = mMapDocument->currentLayer();
-    if (currentLayer == -1)
+    Layer *currentLayer = mMapDocument->currentLayer();
+    if (!currentLayer)
         return;
 
-    Map *map = mMapDocument->map();
-    Layer *layer = map->layerAt(currentLayer);
-    TileLayer *tileLayer = dynamic_cast<TileLayer*>(layer);
-    if (!tileLayer)
-        return;
-
-    const QRegion &selection = mMapDocument->tileSelection();
-    if (selection.isEmpty())
-        return;
+    TileLayer *tileLayer = dynamic_cast<TileLayer*>(currentLayer);
+    const QRegion &tileSelection = mMapDocument->tileSelection();
+    const QList<MapObject*> &selectedObjects = mMapDocument->selectedObjects();
 
     copy();
 
     QUndoStack *stack = mMapDocument->undoStack();
     stack->beginMacro(tr("Cut"));
-    stack->push(new EraseTiles(mMapDocument, tileLayer, selection));
+
+    if (tileLayer && !tileSelection.isEmpty()) {
+        stack->push(new EraseTiles(mMapDocument, tileLayer, tileSelection));
+    } else if (!selectedObjects.isEmpty()) {
+        foreach (MapObject *mapObject, selectedObjects)
+            stack->push(new RemoveMapObject(mMapDocument, mapObject));
+    }
+
     mActionHandler->selectNone();
+
     stack->endMacro();
 }
 
@@ -767,12 +791,16 @@ void MainWindow::paste()
     if (!mMapDocument)
         return;
 
+    Layer *currentLayer = mMapDocument->currentLayer();
+    if (!currentLayer)
+        return;
+
     Map *map = mClipboardManager->map();
     if (!map)
         return;
 
-    // We can currently only handle maps with a single tile layer
-    if (!(map->layerCount() == 1 && map->layerAt(0)->asTileLayer())) {
+    // We can currently only handle maps with a single layer
+    if (map->layerCount() != 1) {
         // Need to clean up the tilesets since they didn't get an owner
         qDeleteAll(map->tilesets());
         delete map;
@@ -783,13 +811,53 @@ void MainWindow::paste()
     tilesetManager->addReferences(map->tilesets());
 
     mMapDocument->unifyTilesets(map);
+    Layer *layer = map->layerAt(0);
 
-    TileLayer *tileLayer = map->layerAt(0)->asTileLayer();
+    if (TileLayer *tileLayer = layer->asTileLayer()) {
+        // Reset selection and paste into the stamp brush
+        mActionHandler->selectNone();
+        setStampBrush(tileLayer);
+        ToolManager::instance()->selectTool(mStampBrush);
+    } else if (ObjectGroup *objectGroup = layer->asObjectGroup()) {
+        if (ObjectGroup *currentObjectGroup = currentLayer->asObjectGroup()) {
+            // Determine where to insert the objects
+            const QPointF center = objectGroup->objectsBoundingRect().center();
+            const MapView *view = mDocumentManager->currentMapView();
 
-    // Reset selection and paste into the stamp brush
-    mActionHandler->selectNone();
-    setStampBrush(tileLayer);
-    ToolManager::instance()->selectTool(mStampBrush);
+            // Take the mouse position if the mouse is on the view, otherwise
+            // take the center of the view.
+            QPoint viewPos;
+            if (view->underMouse())
+                viewPos = view->mapFromGlobal(QCursor::pos());
+            else
+                viewPos = QPoint(view->width() / 2, view->height() / 2);
+
+            const MapRenderer *renderer = mMapDocument->renderer();
+            const QPointF scenePos = view->mapToScene(viewPos);
+            QPointF insertPos = renderer->pixelToTileCoords(scenePos);
+            if (Preferences::instance()->snapToGrid())
+                insertPos = insertPos.toPoint();
+            const QPointF offset = insertPos - center;
+
+            QUndoStack *undoStack = mMapDocument->undoStack();
+            QList<MapObject*> pastedObjects;
+#if QT_VERSION >= 0x040700
+            pastedObjects.reserve(objectGroup->objectCount());
+#endif
+            undoStack->beginMacro(tr("Paste Objects"));
+            foreach (const MapObject *mapObject, objectGroup->objects()) {
+                MapObject *objectClone = mapObject->clone();
+                objectClone->setPosition(objectClone->position() + offset);
+                pastedObjects.append(objectClone);
+                undoStack->push(new AddMapObject(mMapDocument,
+                                                 currentObjectGroup,
+                                                 objectClone));
+            }
+            undoStack->endMacro();
+
+            mMapDocument->setSelectedObjects(pastedObjects);
+        }
+    }
 
     tilesetManager->removeReferences(map->tilesets());
     delete map;
@@ -819,10 +887,10 @@ void MainWindow::zoomNormal()
         mapView->zoomable()->resetZoom();
 }
 
-void MainWindow::newTileset(const QString &path)
+bool MainWindow::newTileset(const QString &path)
 {
     if (!mMapDocument)
-        return;
+        return false;
 
     Map *map = mMapDocument->map();
 
@@ -834,8 +902,18 @@ void MainWindow::newTileset(const QString &path)
     newTileset.setTileWidth(map->tileWidth());
     newTileset.setTileHeight(map->tileHeight());
 
-    if (Tileset *tileset = newTileset.createTileset())
+    if (Tileset *tileset = newTileset.createTileset()) {
         mMapDocument->undoStack()->push(new AddTileset(mMapDocument, tileset));
+        return true;
+    }
+    return false;
+}
+
+void MainWindow::newTilesets(const QStringList &paths)
+{
+    foreach (const QString &path, paths)
+        if (!newTileset(path))
+            return;
 }
 
 void MainWindow::addExternalTileset()
@@ -985,26 +1063,21 @@ void MainWindow::updateRecentFiles()
 void MainWindow::updateActions()
 {
     Map *map = 0;
-    int currentLayer = -1;
     bool tileLayerSelected = false;
+    bool objectsSelected = false;
     QRegion selection;
 
     if (mMapDocument) {
+        Layer *currentLayer = mMapDocument->currentLayer();
+
         map = mMapDocument->map();
-        currentLayer = mMapDocument->currentLayer();
+        tileLayerSelected = dynamic_cast<TileLayer*>(currentLayer) != 0;
+        objectsSelected = !mMapDocument->selectedObjects().isEmpty();
         selection = mMapDocument->tileSelection();
-
-        if (currentLayer != -1) {
-            Layer *layer = mMapDocument->map()->layerAt(currentLayer);
-            tileLayerSelected = dynamic_cast<TileLayer*>(layer) != 0;
-        }
-
-        mCommandButton->setEnabled(true);
-    } else {
-        mCommandButton->setEnabled(false);
     }
 
-    const bool mapInClipboard = mClipboardManager->hasMap();
+    const bool canCopy = (tileLayerSelected && !selection.isEmpty())
+            || objectsSelected;
 
     mUi->actionSave->setEnabled(map);
     mUi->actionSaveAs->setEnabled(map);
@@ -1012,9 +1085,9 @@ void MainWindow::updateActions()
     mUi->actionExport->setEnabled(map);
     mUi->actionClose->setEnabled(map);
     mUi->actionCloseAll->setEnabled(map);
-    mUi->actionCut->setEnabled(tileLayerSelected && !selection.isEmpty());
-    mUi->actionCopy->setEnabled(tileLayerSelected && !selection.isEmpty());
-    mUi->actionPaste->setEnabled(tileLayerSelected && mapInClipboard);
+    mUi->actionCut->setEnabled(canCopy);
+    mUi->actionCopy->setEnabled(canCopy);
+    mUi->actionPaste->setEnabled(mClipboardManager->hasMap());
     mUi->actionNewTileset->setEnabled(map);
     mUi->actionAddExternalTileset->setEnabled(map);
     mUi->actionResizeMap->setEnabled(map);
@@ -1022,6 +1095,8 @@ void MainWindow::updateActions()
     mUi->actionMapProperties->setEnabled(map);
     mUi->actionAutoMap->setEnabled(map);
 
+    mCommandButton->setEnabled(map);
+
     updateZoomLabel(); // for the zoom actions
 }
 
@@ -1046,24 +1121,45 @@ void MainWindow::editLayerProperties()
     if (!mMapDocument)
         return;
 
-    const int layerIndex = mMapDocument->currentLayer();
-    if (layerIndex == -1)
-        return;
+    if (Layer *layer = mMapDocument->currentLayer())
+        PropertiesDialog::showDialogFor(layer, mMapDocument, this);
+}
 
-    Layer *layer = mMapDocument->map()->layerAt(layerIndex);
-    PropertiesDialog::showDialogFor(layer, mMapDocument, this);
+void MainWindow::flipStampHorizontally()
+{
+    if (TileLayer *stamp = mStampBrush->stamp()) {
+        stamp = static_cast<TileLayer*>(stamp->clone());
+        stamp->flip(TileLayer::FlipHorizontally);
+        setStampBrush(stamp);
+    }
+}
+
+void MainWindow::flipStampVertically()
+{
+    if (TileLayer *stamp = mStampBrush->stamp()) {
+        stamp = static_cast<TileLayer*>(stamp->clone());
+        stamp->flip(TileLayer::FlipVertically);
+        setStampBrush(stamp);
+    }
 }
 
 /**
- * Sets the stamp brush in response to a change in the selection in the tileset
- * view.
+ * Sets the stamp brush, which is used by both the stamp brush and the bucket
+ * fill tool.
  */
 void MainWindow::setStampBrush(const TileLayer *tiles)
 {
-    if (tiles) {
-        mStampBrush->setStamp(static_cast<TileLayer*>(tiles->clone()));
-        mBucketFillTool->setStamp(static_cast<TileLayer*>(tiles->clone()));
-    }
+    if (!tiles)
+        return;
+
+    mStampBrush->setStamp(static_cast<TileLayer*>(tiles->clone()));
+    mBucketFillTool->setStamp(static_cast<TileLayer*>(tiles->clone()));
+
+    // When selecting a new stamp, it makes sense to switch to a stamp tool
+    ToolManager *m = ToolManager::instance();
+    AbstractTool *selectedTool = m->selectedTool();
+    if (selectedTool != mStampBrush && selectedTool != mBucketFillTool)
+        m->selectTool(mStampBrush);
 }
 
 void MainWindow::updateStatusInfoLabel(const QString &statusInfo)
@@ -1079,28 +1175,28 @@ void MainWindow::writeSettings()
     mSettings.endGroup();
 
     mSettings.beginGroup(QLatin1String("recentFiles"));
-    mSettings.setValue(QLatin1String("recentOpenedFiles"),
-                       mDocumentManager->documentCount());
-
     if (MapDocument *document = mDocumentManager->currentDocument())
         mSettings.setValue(QLatin1String("lastActive"), document->fileName());
 
+    QStringList fileList;
     QStringList mapScales;
     QStringList scrollX;
     QStringList scrollY;
     QStringList selectedLayer;
     for (int i = 0; i < mDocumentManager->documentCount(); i++) {
         mDocumentManager->switchToDocument(i);
+        fileList.append(mDocumentManager->currentDocument()->fileName());
         MapView *mapView = mDocumentManager->currentMapView();
+        const int currentLayerIndex = mMapDocument->currentLayerIndex();
 
         mapScales.append(QString::number(mapView->zoomable()->scale()));
         scrollX.append(QString::number(
                        mapView->horizontalScrollBar()->sliderPosition()));
         scrollY.append(QString::number(
                        mapView->verticalScrollBar()->sliderPosition()));
-        selectedLayer.append(QString::number(mMapDocument->currentLayer()));
-
+        selectedLayer.append(QString::number(currentLayerIndex));
     }
+    mSettings.setValue(QLatin1String("lastOpenFiles"), fileList);
     mSettings.setValue(QLatin1String("mapScale"), mapScales);
     mSettings.setValue(QLatin1String("scrollX"), scrollX);
     mSettings.setValue(QLatin1String("scrollY"), scrollY);
@@ -1176,13 +1272,16 @@ void MainWindow::mapDocumentChanged(MapDocument *mapDocument)
     mLayerDock->setMapDocument(mMapDocument);
     mTilesetDock->setMapDocument(mMapDocument);
     AutomaticMappingManager::instance()->setMapDocument(mMapDocument);
+    QuickStampManager::instance()->setMapDocument(mMapDocument);
 
     if (mMapDocument) {
         connect(mMapDocument, SIGNAL(fileNameChanged()),
                 SLOT(updateWindowTitle()));
-        connect(mMapDocument, SIGNAL(currentLayerChanged(int)),
+        connect(mapDocument, SIGNAL(currentLayerIndexChanged(int)),
                 SLOT(updateActions()));
-        connect(mMapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
+        connect(mapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
+                SLOT(updateActions()));
+        connect(mapDocument, SIGNAL(selectedObjectsChanged()),
                 SLOT(updateActions()));
     }
 
@@ -1192,22 +1291,12 @@ void MainWindow::mapDocumentChanged(MapDocument *mapDocument)
 
 void MainWindow::setupQuickStamps()
 {
-    QList<int> keys;
-    keys << Qt::Key_1
-         << Qt::Key_2
-         << Qt::Key_3
-         << Qt::Key_4
-         << Qt::Key_5
-         << Qt::Key_6
-         << Qt::Key_7
-         << Qt::Key_8
-         << Qt::Key_9;
+    QuickStampManager *quickStampManager = QuickStampManager::instance();
+    QList<int> keys = QuickStampManager::keys();
 
     QSignalMapper *selectMapper = new QSignalMapper(this);
     QSignalMapper *saveMapper = new QSignalMapper(this);
 
-    mQuickStamps.resize(keys.size());
-
     for (int i = 0; i < keys.length(); i++) {
         // Set up shortcut for selecting this quick stamp
         QShortcut *selectStamp = new QShortcut(this);
@@ -1222,84 +1311,13 @@ void MainWindow::setupQuickStamps()
         saveMapper->setMapping(saveStamp, i);
     }
 
-    connect(selectMapper, SIGNAL(mapped(int)), SLOT(selectQuickStamp(int)));
-    connect(saveMapper, SIGNAL(mapped(int)), SLOT(saveQuickStamp(int)));
-}
+    connect(selectMapper, SIGNAL(mapped(int)),
+            quickStampManager, SLOT(selectQuickStamp(int)));
+    connect(saveMapper, SIGNAL(mapped(int)),
+            quickStampManager, SLOT(saveQuickStamp(int)));
 
-void MainWindow::cleanQuickStamps()
-{
-    for (int i = 0; i < mQuickStamps.size(); i++)
-        eraseQuickStamp(i);
-}
-
-void MainWindow::eraseQuickStamp(int index)
-{
-    if (Map *quickStamp = mQuickStamps.at(index)) {
-        // Decrease reference to tilesets
-        TilesetManager *tilesetManager = TilesetManager::instance();
-        tilesetManager->removeReferences(quickStamp->tilesets());
-        delete quickStamp;
-    }
-}
-
-void MainWindow::selectQuickStamp(int index)
-{
-    if (!mMapDocument)
-        return;
-
-    if (Map *stampMap = mQuickStamps.at(index)) {
-        mMapDocument->unifyTilesets(stampMap);
-        setStampBrush(stampMap->layerAt(0)->asTileLayer());
-        ToolManager::instance()->selectTool(mStampBrush);
-    }
-}
-
-void MainWindow::saveQuickStamp(int index)
-{
-    const Map *map = mMapDocument->map();
-
-    // The source of the saved stamp depends on which tool is selected
-    AbstractTool *selectedTool = ToolManager::instance()->selectedTool();
-    TileLayer *copy = 0;
-    if (selectedTool == mStampBrush) {
-        TileLayer *stamp = mStampBrush->stamp();
-        if (!stamp)
-            return;
-
-        copy = static_cast<TileLayer*>(stamp->clone());
-    } else {
-        int currentLayer = mMapDocument->currentLayer();
-        if (currentLayer == -1)
-            return;
-
-        const TileLayer *tileLayer =
-                map->layerAt(currentLayer)->asTileLayer();
-        if (!tileLayer)
-            return;
-
-        const QRegion &selection = mMapDocument->tileSelection();
-        if (selection.isEmpty())
-            return;
-
-        copy = tileLayer->copy(selection.translated(-tileLayer->x(),
-                                                    -tileLayer->y()));
-    }
-
-    Map *copyMap = new Map(map->orientation(),
-                           copy->width(), copy->height(),
-                           map->tileWidth(), map->tileHeight());
-
-    copyMap->addLayer(copy);
-
-    // Add tileset references to map and tileset manager
-    TilesetManager *tilesetManager = TilesetManager::instance();
-    foreach (Tileset *tileset, copy->usedTilesets()) {
-        copyMap->addTileset(tileset);
-        tilesetManager->addReference(tileset);
-    }
-
-    eraseQuickStamp(index);
-    mQuickStamps.replace(index, copyMap);
+    connect(quickStampManager, SIGNAL(setStampBrush(const TileLayer*)),
+            this, SLOT(setStampBrush(const TileLayer*)));
 }
 
 void MainWindow::closeMapDocument(int index)
