@@ -20,7 +20,8 @@
 
 #include "mapdocumentactionhandler.h"
 
-#include "changeselection.h"
+#include "changetileselection.h"
+#include "layer.h"
 #include "map.h"
 #include "mapdocument.h"
 #include "utils.h"
@@ -44,6 +45,8 @@ MapDocumentActionHandler::MapDocumentActionHandler(QObject *parent)
     mActionSelectNone = new QAction(this);
     mActionSelectNone->setShortcut(tr("Ctrl+Shift+A"));
 
+    mActionCropToSelection = new QAction(this);
+
     mActionAddTileLayer = new QAction(this);
     mActionAddObjectGroup = new QAction(this);
 
@@ -52,10 +55,18 @@ MapDocumentActionHandler::MapDocumentActionHandler(QObject *parent)
     mActionDuplicateLayer->setIcon(
             QIcon(QLatin1String(":/images/16x16/stock-duplicate-16.png")));
 
+    mActionMergeLayerDown = new QAction(this);
+
     mActionRemoveLayer = new QAction(this);
     mActionRemoveLayer->setIcon(
             QIcon(QLatin1String(":/images/16x16/edit-delete.png")));
 
+    mActionSelectPreviousLayer = new QAction(this);
+    mActionSelectPreviousLayer->setShortcut(tr("PgUp"));
+
+    mActionSelectNextLayer = new QAction(this);
+    mActionSelectNextLayer->setShortcut(tr("PgDown"));
+
     mActionMoveLayerUp = new QAction(this);
     mActionMoveLayerUp->setShortcut(tr("Ctrl+Shift+Up"));
     mActionMoveLayerUp->setIcon(
@@ -66,6 +77,11 @@ MapDocumentActionHandler::MapDocumentActionHandler(QObject *parent)
     mActionMoveLayerDown->setIcon(
             QIcon(QLatin1String(":/images/16x16/go-down.png")));
 
+    mActionToggleOtherLayers = new QAction(this);
+    mActionToggleOtherLayers->setShortcut(tr("Ctrl+Shift+H"));
+    mActionToggleOtherLayers->setIcon(
+            QIcon(QLatin1String(":/images/16x16/show_hide_others.png")));
+
     mActionLayerProperties = new QAction(this);
     mActionLayerProperties->setIcon(
             QIcon(QLatin1String(":images/16x16/document-properties.png")));
@@ -77,14 +93,24 @@ MapDocumentActionHandler::MapDocumentActionHandler(QObject *parent)
 
     connect(mActionSelectAll, SIGNAL(triggered()), SLOT(selectAll()));
     connect(mActionSelectNone, SIGNAL(triggered()), SLOT(selectNone()));
+    connect(mActionCropToSelection, SIGNAL(triggered()),
+            SLOT(cropToSelection()));
     connect(mActionAddTileLayer, SIGNAL(triggered()), SLOT(addTileLayer()));
     connect(mActionAddObjectGroup, SIGNAL(triggered()),
             SLOT(addObjectGroup()));
     connect(mActionDuplicateLayer, SIGNAL(triggered()),
             SLOT(duplicateLayer()));
+    connect(mActionMergeLayerDown, SIGNAL(triggered()),
+            SLOT(mergeLayerDown()));
+    connect(mActionSelectPreviousLayer, SIGNAL(triggered()),
+            SLOT(selectPreviousLayer()));
+    connect(mActionSelectNextLayer, SIGNAL(triggered()),
+            SLOT(selectNextLayer()));
     connect(mActionRemoveLayer, SIGNAL(triggered()), SLOT(removeLayer()));
     connect(mActionMoveLayerUp, SIGNAL(triggered()), SLOT(moveLayerUp()));
     connect(mActionMoveLayerDown, SIGNAL(triggered()), SLOT(moveLayerDown()));
+    connect(mActionToggleOtherLayers, SIGNAL(triggered()),
+            SLOT(toggleOtherLayers()));
 
     updateActions();
     retranslateUi();
@@ -100,12 +126,18 @@ void MapDocumentActionHandler::retranslateUi()
     mActionSelectAll->setText(tr("Select &All"));
     mActionSelectNone->setText(tr("Select &None"));
 
-    mActionAddTileLayer->setText(tr("Add &Tile Layer..."));
-    mActionAddObjectGroup->setText(tr("Add &Object Layer..."));
+    mActionCropToSelection->setText(tr("&Crop to Selection"));
+
+    mActionAddTileLayer->setText(tr("Add &Tile Layer"));
+    mActionAddObjectGroup->setText(tr("Add &Object Layer"));
     mActionDuplicateLayer->setText(tr("&Duplicate Layer"));
+    mActionMergeLayerDown->setText(tr("&Merge Layer Down"));
     mActionRemoveLayer->setText(tr("&Remove Layer"));
-    mActionMoveLayerUp->setText(tr("Move Layer &Up"));
-    mActionMoveLayerDown->setText(tr("Move Layer Dow&n"));
+    mActionSelectPreviousLayer->setText(tr("Select Pre&vious Layer"));
+    mActionSelectNextLayer->setText(tr("Select &Next Layer"));
+    mActionMoveLayerUp->setText(tr("R&aise Layer"));
+    mActionMoveLayerDown->setText(tr("&Lower Layer"));
+    mActionToggleOtherLayers->setText(tr("Show/&Hide all Other Layers"));
     mActionLayerProperties->setText(tr("Layer &Properties..."));
 }
 
@@ -114,11 +146,14 @@ void MapDocumentActionHandler::setMapDocument(MapDocument *mapDocument)
     if (mMapDocument == mapDocument)
         return;
 
+    if (mMapDocument)
+        mMapDocument->disconnect(this);
+
     mMapDocument = mapDocument;
     updateActions();
 
     if (mMapDocument) {
-        connect(mapDocument, SIGNAL(currentLayerChanged(int)),
+        connect(mapDocument, SIGNAL(currentLayerIndexChanged(int)),
                 SLOT(updateActions()));
         connect(mapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
                 SLOT(updateActions()));
@@ -137,7 +172,7 @@ void MapDocumentActionHandler::selectAll()
     if (mMapDocument->tileSelection() == all)
         return;
 
-    QUndoCommand *command = new ChangeSelection(mMapDocument, all);
+    QUndoCommand *command = new ChangeTileSelection(mMapDocument, all);
     mMapDocument->undoStack()->push(command);
 }
 
@@ -149,10 +184,22 @@ void MapDocumentActionHandler::selectNone()
     if (mMapDocument->tileSelection().isEmpty())
         return;
 
-    QUndoCommand *command = new ChangeSelection(mMapDocument, QRegion());
+    QUndoCommand *command = new ChangeTileSelection(mMapDocument, QRegion());
     mMapDocument->undoStack()->push(command);
 }
 
+void MapDocumentActionHandler::cropToSelection()
+{
+    if (!mMapDocument)
+        return;
+
+    const QRect bounds = mMapDocument->tileSelection().boundingRect();
+    if (bounds.isNull())
+        return;
+
+    mMapDocument->resizeMap(bounds.size(), -bounds.topLeft());
+}
+
 void MapDocumentActionHandler::addTileLayer()
 {
     if (mMapDocument)
@@ -171,47 +218,93 @@ void MapDocumentActionHandler::duplicateLayer()
         mMapDocument->duplicateLayer();
 }
 
+void MapDocumentActionHandler::mergeLayerDown()
+{
+    if (mMapDocument)
+        mMapDocument->mergeLayerDown();
+}
+
+void MapDocumentActionHandler::selectPreviousLayer()
+{
+    if (mMapDocument) {
+        const int currentLayer = mMapDocument->currentLayerIndex();
+        if (currentLayer < mMapDocument->map()->layerCount() - 1)
+            mMapDocument->setCurrentLayerIndex(currentLayer + 1);
+    }
+}
+
+void MapDocumentActionHandler::selectNextLayer()
+{
+    if (mMapDocument) {
+        const int currentLayer = mMapDocument->currentLayerIndex();
+        if (currentLayer > 0)
+            mMapDocument->setCurrentLayerIndex(currentLayer - 1);
+    }
+}
+
 void MapDocumentActionHandler::moveLayerUp()
 {
     if (mMapDocument)
-        mMapDocument->moveLayerUp(mMapDocument->currentLayer());
+        mMapDocument->moveLayerUp(mMapDocument->currentLayerIndex());
 }
 
 void MapDocumentActionHandler::moveLayerDown()
 {
     if (mMapDocument)
-        mMapDocument->moveLayerDown(mMapDocument->currentLayer());
+        mMapDocument->moveLayerDown(mMapDocument->currentLayerIndex());
 }
 
 void MapDocumentActionHandler::removeLayer()
 {
     if (mMapDocument)
-        mMapDocument->removeLayer(mMapDocument->currentLayer());
+        mMapDocument->removeLayer(mMapDocument->currentLayerIndex());
+}
+
+void MapDocumentActionHandler::toggleOtherLayers()
+{
+    if (mMapDocument)
+        mMapDocument->toggleOtherLayers(mMapDocument->currentLayerIndex());
 }
 
 void MapDocumentActionHandler::updateActions()
 {
     Map *map = 0;
-    int currentLayer = -1;
+    int currentLayerIndex = -1;
     QRegion selection;
+    bool canMergeDown = false;
 
     if (mMapDocument) {
         map = mMapDocument->map();
-        currentLayer = mMapDocument->currentLayer();
+        currentLayerIndex = mMapDocument->currentLayerIndex();
         selection = mMapDocument->tileSelection();
+
+        if (currentLayerIndex > 0) {
+            Layer *upper = map->layerAt(currentLayerIndex);
+            Layer *lower = map->layerAt(currentLayerIndex - 1);
+            canMergeDown = lower->canMergeWith(upper);
+        }
     }
 
     mActionSelectAll->setEnabled(map);
     mActionSelectNone->setEnabled(!selection.isEmpty());
 
+    mActionCropToSelection->setEnabled(!selection.isEmpty());
+
     mActionAddTileLayer->setEnabled(map);
     mActionAddObjectGroup->setEnabled(map);
 
     const int layerCount = map ? map->layerCount() : 0;
-    mActionDuplicateLayer->setEnabled(currentLayer >= 0);
-    mActionMoveLayerUp->setEnabled(currentLayer >= 0 &&
-                                   currentLayer < layerCount - 1);
-    mActionMoveLayerDown->setEnabled(currentLayer > 0);
-    mActionRemoveLayer->setEnabled(currentLayer >= 0);
-    mActionLayerProperties->setEnabled(currentLayer >= 0);
+    const bool hasPreviousLayer = currentLayerIndex >= 0
+            && currentLayerIndex < layerCount - 1;
+    const bool hasNextLayer = currentLayerIndex > 0;
+
+    mActionDuplicateLayer->setEnabled(currentLayerIndex >= 0);
+    mActionMergeLayerDown->setEnabled(canMergeDown);
+    mActionSelectPreviousLayer->setEnabled(hasPreviousLayer);
+    mActionSelectNextLayer->setEnabled(hasNextLayer);
+    mActionMoveLayerUp->setEnabled(hasPreviousLayer);
+    mActionMoveLayerDown->setEnabled(hasNextLayer);
+    mActionToggleOtherLayers->setEnabled(layerCount > 1);
+    mActionRemoveLayer->setEnabled(currentLayerIndex >= 0);
+    mActionLayerProperties->setEnabled(currentLayerIndex >= 0);
 }
