@@ -51,12 +51,19 @@ public:
 
     QAction *actionSelectAll() const { return mActionSelectAll; }
     QAction *actionSelectNone() const { return mActionSelectNone; }
+    QAction *actionCropToSelection() const { return mActionCropToSelection; }
     QAction *actionAddTileLayer() const { return mActionAddTileLayer; }
     QAction *actionAddObjectGroup() const { return mActionAddObjectGroup; }
     QAction *actionDuplicateLayer() const { return mActionDuplicateLayer; }
+    QAction *actionMergeLayerDown() const { return mActionMergeLayerDown; }
     QAction *actionRemoveLayer() const { return mActionRemoveLayer; }
+    QAction *actionSelectPreviousLayer() const
+    { return mActionSelectPreviousLayer; }
+    QAction *actionSelectNextLayer() const { return mActionSelectNextLayer; }
     QAction *actionMoveLayerUp() const { return mActionMoveLayerUp; }
     QAction *actionMoveLayerDown() const { return mActionMoveLayerDown; }
+    QAction *actionToggleOtherLayers() const
+    { return mActionToggleOtherLayers; }
     QAction *actionLayerProperties() const { return mActionLayerProperties; }
 
 signals:
@@ -66,12 +73,18 @@ public slots:
     void selectAll();
     void selectNone();
 
+    void cropToSelection();
+
     void addTileLayer();
     void addObjectGroup();
     void duplicateLayer();
+    void mergeLayerDown();
+    void selectPreviousLayer();
+    void selectNextLayer();
     void moveLayerUp();
     void moveLayerDown();
     void removeLayer();
+    void toggleOtherLayers();
 
 private slots:
     void updateActions();
@@ -81,12 +94,17 @@ private:
 
     QAction *mActionSelectAll;
     QAction *mActionSelectNone;
+    QAction *mActionCropToSelection;
     QAction *mActionAddTileLayer;
     QAction *mActionAddObjectGroup;
     QAction *mActionDuplicateLayer;
+    QAction *mActionMergeLayerDown;
     QAction *mActionRemoveLayer;
+    QAction *mActionSelectPreviousLayer;
+    QAction *mActionSelectNextLayer;
     QAction *mActionMoveLayerUp;
     QAction *mActionMoveLayerDown;
+    QAction *mActionToggleOtherLayers;
     QAction *mActionLayerProperties;
 
     static MapDocumentActionHandler *mInstance;
