@@ -32,9 +32,54 @@
         <translation>Eigenschaften</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+24"/>
+        <source>&amp;Save map before executing</source>
+        <translation>&amp;Speichere Karte vor der Ausführung</translation>
+    </message>
+    <message>
         <source>Save map before executing</source>
-        <translation>Speichern vor der Ausführung</translation>
+        <translation type="obsolete">Speichern vor der Ausführung</translation>
+    </message>
+</context>
+<context>
+    <name>Droidcraft::DroidcraftPlugin</name>
+    <message>
+        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
+        <source>This is not a valid Droidcraft map file!</source>
+        <translation>Dies ist keine valide Droidcraft Datei!</translation>
+    </message>
+    <message>
+        <location line="+44"/>
+        <source>The map needs to have exactly one tile layer!</source>
+        <translation>Diese Karte benötigt exakt eine Kachelebene!</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>The layer must have a size of 48 x 48 tiles!</source>
+        <translation>Die Ebene muss eine Größe von 48 x 48 Kacheln haben!</translation>
+    </message>
+    <message>
+        <location line="+22"/>
+        <source>Could not open file for writing.</source>
+        <translation>Konnte Datei zum schreiben nicht öffnen.</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Droidcraft map files (*.dat)</source>
+        <translation>Droidcraft Kartendateien (*.dat)</translation>
+    </message>
+</context>
+<context>
+    <name>Lua::LuaPlugin</name>
+    <message>
+        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
+        <source>Could not open file for writing.</source>
+        <translation>Konnte Datei zum schreiben nicht öffnen.</translation>
+    </message>
+    <message>
+        <location line="+16"/>
+        <source>Lua files (*.lua)</source>
+        <translation>Lua Dateien (*.lua)</translation>
     </message>
 </context>
 <context>
@@ -137,7 +182,7 @@
     <message>
         <location line="+3"/>
         <source>Ctrl+G</source>
-        <translation>Strg+G</translation>
+        <translation></translation>
     </message>
     <message>
         <location line="+9"/>
@@ -177,12 +222,16 @@
     <message>
         <location line="+3"/>
         <source>Ctrl+0</source>
-        <translation>Strg+0</translation>
+        <translation></translation>
     </message>
     <message>
         <location line="+5"/>
+        <source>Save As &amp;Image...</source>
+        <translation>Speichern als &amp;Bild...</translation>
+    </message>
+    <message>
         <source>Save As Image...</source>
-        <translation>Speichern als Bild...</translation>
+        <translation type="obsolete">Speichern als Bild...</translation>
     </message>
     <message>
         <location line="+12"/>
@@ -217,7 +266,7 @@
     <message>
         <location line="+3"/>
         <source>Ctrl+E</source>
-        <translation>Strg+E</translation>
+        <translation></translation>
     </message>
     <message>
         <location line="+5"/>
@@ -237,13 +286,13 @@
     <message>
         <location line="+3"/>
         <source>Ctrl+Shift+W</source>
-        <translation>Strg+Shift+W</translation>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>MapReader</name>
     <message>
-        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
+        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
         <source>Not a map file.</source>
         <translation>Keine Kartendatei.</translation>
     </message>
@@ -272,7 +321,7 @@ Zeile %1, Spalte %2</translation>
         <translation>Datei nicht lesbar: %1</translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+44"/>
         <source>Unsupported map orientation: &quot;%1&quot;</source>
         <translation>Nicht unterstützte Kartenorientierung: &quot;%1&quot;</translation>
     </message>
@@ -305,19 +354,19 @@ Zeile %1, Spalte %2</translation>
     </message>
     <message>
         <location line="+11"/>
-        <location line="+66"/>
+        <location line="+72"/>
         <location line="+39"/>
-        <location line="+103"/>
+        <location line="+90"/>
         <source>Invalid tile: %1</source>
         <translation>Ungültige Kachel: %1</translation>
     </message>
     <message>
-        <location line="-188"/>
+        <location line="-181"/>
         <source>Unknown encoding: %1</source>
         <translation>Unbekannte Codierung: %1</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+25"/>
         <source>Compression method &apos;%1&apos; not supported</source>
         <translation>Komprimierungsmethode &apos;%1&apos; nicht unterstützt</translation>
     </message>
@@ -333,21 +382,53 @@ Zeile %1, Spalte %2</translation>
         <translation>Kann Kachel an (%1, %2) auf Layer &apos;%3&apos; nicht parsen</translation>
     </message>
     <message>
-        <location line="+20"/>
         <source>Invalid global tile id (less than 0): %1</source>
-        <translation>Ungültige globale Kachel-ID (kleiner als 0): %1</translation>
+        <translation type="obsolete">Ungültige globale Kachel-ID (kleiner als 0): %1</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+20"/>
         <source>Tile used but no tilesets specified</source>
         <translation>Kachel benutzt aber keine Tilesets angegeben</translation>
     </message>
     <message>
-        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
+        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
         <source>Could not open file for writing.</source>
         <translation>Konnte Datei nicht zum Schreiben öffnen.</translation>
     </message>
 </context>
+<context>
+    <name>NewImageLayerDialog</name>
+    <message>
+        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
+        <source>New Tileset</source>
+        <translation>Neues Tileset</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Image layer</source>
+        <translation>Bildebene</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>&amp;Name:</source>
+        <translation>&amp;Name:</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Image:</source>
+        <translation>Bild:</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>&amp;Browse...</source>
+        <translation>&amp;Durchsuchen...</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Use transparent color:</source>
+        <translation>Nutze Transparenzfarbe:</translation>
+    </message>
+</context>
 <context>
     <name>NewMapDialog</name>
     <message>
@@ -638,7 +719,7 @@ Zeile %1, Spalte %2</translation>
     <message>
         <location line="+13"/>
         <source>Hardware &amp;accelerated drawing (OpenGL)</source>
-        <translation>Hardwarebeschleunigtes Zeichnen (OpenGL)</translation>
+        <translation>Hardware&amp;beschleunigtes Zeichnen (OpenGL)</translation>
     </message>
 </context>
 <context>
@@ -743,6 +824,41 @@ Zeile %1, Spalte %2</translation>
         <translation>T-Engine4 Kartendateien (*.lua)</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::AbstractObjectTool</name>
+    <message numerus="yes">
+        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
+        <location line="+54"/>
+        <source>Duplicate %n Object(s)</source>
+        <translation>
+            <numerusform>Dupliziere Objekt</numerusform>
+            <numerusform>Dupliziere %n Objekte</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-53"/>
+        <location line="+71"/>
+        <source>Remove %n Object(s)</source>
+        <translation>
+            <numerusform>Entferne Objekt</numerusform>
+            <numerusform>Entferne %n Objekte</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-62"/>
+        <location line="+72"/>
+        <source>Move %n Object(s) to Layer</source>
+        <translation>
+            <numerusform>Verschiebe Objekt zu anderer Ebene</numerusform>
+            <numerusform>Verschiebe %n Objekte zu anderer Ebene</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location line="-62"/>
+        <source>Object &amp;Properties...</source>
+        <translation>Objekt&amp;eigenschaften...</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::AutoMapper</name>
     <message>
@@ -751,7 +867,7 @@ Zeile %1, Spalte %2</translation>
         <translation>Multiple Ebenen vom Typ %1 gefunden!</translation>
     </message>
     <message>
-        <location line="+115"/>
+        <location line="+110"/>
         <source>No ruleRegions layer found!</source>
         <translation>Keine ruleRegions Ebene gefunden!</translation>
     </message>
@@ -766,7 +882,7 @@ Zeile %1, Spalte %2</translation>
         <translation>Keine ruleSet Ebene gefunden!</translation>
     </message>
     <message>
-        <location line="+208"/>
+        <location line="+212"/>
         <source>Tile</source>
         <translation>Kachel</translation>
     </message>
@@ -774,12 +890,12 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::AutomaticMappingManager</name>
     <message>
-        <location line="+491"/>
+        <location line="+497"/>
         <source>No set layer found!</source>
         <translation>Keine set Ebene gefunden!</translation>
     </message>
     <message>
-        <location line="+29"/>
+        <location line="+27"/>
         <source>Apply AutoMap rules</source>
         <translation>AutoMap Regeln anwenden</translation>
     </message>
@@ -830,7 +946,7 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::CommandButton</name>
     <message>
-        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
+        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
         <source>Execute Command</source>
         <translation>Kommando ausführen</translation>
     </message>
@@ -840,13 +956,12 @@ Zeile %1, Spalte %2</translation>
         <translation>F5</translation>
     </message>
     <message>
-        <location line="+39"/>
-        <location line="+61"/>
+        <location line="+24"/>
         <source>Error Executing Command</source>
         <translation>Fehler beim Ausführen des Kommandos</translation>
     </message>
     <message>
-        <location line="-60"/>
+        <location line="+1"/>
         <source>You do not have any commands setup.</source>
         <translation>Es wurden keine Kommandos definiert.</translation>
     </message>
@@ -856,25 +971,24 @@ Zeile %1, Spalte %2</translation>
         <translation>Kommandos editieren...</translation>
     </message>
     <message>
-        <location line="+50"/>
+        <location line="+45"/>
         <source>Edit Commands...</source>
         <translation>Kommandos editieren...</translation>
     </message>
     <message>
-        <location line="+9"/>
         <source>There was an error running the command</source>
-        <translation>Bei der Ausführung des Kommandos ist ein Fehler aufgetreten</translation>
+        <translation type="obsolete">Bei der Ausführung des Kommandos ist ein Fehler aufgetreten</translation>
     </message>
 </context>
 <context>
     <name>Tiled::Internal::CommandDataModel</name>
     <message>
-        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
+        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
         <source>Open in text editor</source>
         <translation>In Texteditor öffnen</translation>
     </message>
     <message>
-        <location line="+90"/>
+        <location line="+92"/>
         <location line="+67"/>
         <source>&lt;new command&gt;</source>
         <translation>&lt;neues Kommando&gt;</translation>
@@ -900,7 +1014,7 @@ Zeile %1, Spalte %2</translation>
         <translation>Neues Kommando hinzufügen</translation>
     </message>
     <message>
-        <location line="+100"/>
+        <location line="+101"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
@@ -914,20 +1028,93 @@ Zeile %1, Spalte %2</translation>
         <source>Enable</source>
         <translation>Aktivieren</translation>
     </message>
+    <message>
+        <location line="+14"/>
+        <source>Move Up</source>
+        <translation>Nach oben bewegen</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Move Down</source>
+        <translation>Nach unten bewegen</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Execute</source>
+        <translation>Ausführen</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Execute in Terminal</source>
+        <translation>Im Terminal ausführen</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
+    <message>
+        <location line="+84"/>
+        <source>%1 (copy)</source>
+        <translation>%1 (kopieren)</translation>
+    </message>
+    <message>
+        <location line="+16"/>
+        <source>New command</source>
+        <translation>Neues Kommando</translation>
+    </message>
 </context>
 <context>
     <name>Tiled::Internal::CommandDialog</name>
     <message>
-        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
+        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
         <source>Edit Commands</source>
         <translation>Kommandos bearbeiten</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::CommandProcess</name>
+    <message>
+        <location filename="../src/tiled/command.cpp" line="+122"/>
+        <source>Unable to create/open %1</source>
+        <translation>%1 konnte nicht erzeugt bzw. geöffnet werden</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Unable to add executable permissions to %1</source>
+        <translation>%1 konnten keine Berechtigungen zur Ausführung hinzugefügt werden</translation>
+    </message>
+    <message>
+        <location line="+26"/>
+        <source>The command failed to start.</source>
+        <translation>Dieses Kommando konnte nicht ausgeführt werden.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>The command crashed.</source>
+        <translation>Das Kommando führte zu einem Absturz.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>The command timed out.</source>
+        <translation>Das Kommando benötigte zu lange (Timeout).</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>An unknown error occurred.</source>
+        <translation>Ein unbekannter Fehler ist aufgetreten.</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Error Executing %1</source>
+        <translation>Fehler bei der Ausführung %1</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::CreateObjectTool</name>
     <message>
         <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
-        <location line="+111"/>
+        <location line="+100"/>
         <source>O</source>
         <translation>O</translation>
     </message>
@@ -962,10 +1149,38 @@ Zeile %1, Spalte %2</translation>
         <translation>E</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
+    <message>
+        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
+        <source>Image Layer</source>
+        <translation>Bildebene</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Browse...</source>
+        <translation>Durchsuchen...</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Image:</source>
+        <translation>Bild:</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Transparent color:</source>
+        <translation>Transparenzfarbe:</translation>
+    </message>
+    <message>
+        <location line="+17"/>
+        <source>Layer Image</source>
+        <translation>Ebenenbild:</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::LayerDock</name>
     <message>
-        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
+        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
         <source>Layers</source>
         <translation>Ebenen</translation>
     </message>
@@ -986,19 +1201,19 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::MainWindow</name>
     <message>
-        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
-        <location line="+10"/>
+        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
+        <location line="+8"/>
         <source>Undo</source>
         <translation>Rückgängig</translation>
     </message>
     <message>
-        <location line="-9"/>
-        <location line="+8"/>
+        <location line="-7"/>
+        <location line="+6"/>
         <source>Redo</source>
         <translation>Wiederherstellen</translation>
     </message>
     <message>
-        <location line="+32"/>
+        <location line="+30"/>
         <source>Ctrl+=</source>
         <translation>Ctrl+=</translation>
     </message>
@@ -1013,36 +1228,56 @@ Zeile %1, Spalte %2</translation>
         <translation>-</translation>
     </message>
     <message>
-        <location line="+19"/>
-        <location line="+962"/>
+        <location line="+22"/>
+        <location line="+1047"/>
         <source>&amp;Layer</source>
         <translation>&amp;Ebene</translation>
     </message>
     <message>
-        <location line="-711"/>
+        <location line="-910"/>
+        <source>Ctrl+PgUp</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Ctrl+PgDown</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
+    <message>
+        <location line="+127"/>
         <source>Error Opening Map</source>
         <translation>Fehler beim öffnen der Karte</translation>
     </message>
     <message>
-        <location line="+69"/>
-        <location line="+138"/>
+        <location line="+73"/>
+        <location line="+135"/>
         <source>All Files (*)</source>
         <translation>Alle Dateien (*)</translation>
     </message>
     <message>
-        <location line="-135"/>
-        <location line="+79"/>
+        <location line="-132"/>
+        <location line="+76"/>
         <source>Tiled map files (*.tmx)</source>
         <translation>Tiled Karten (*.tmx)</translation>
     </message>
     <message>
-        <location line="-66"/>
+        <location line="-63"/>
         <source>Open Map</source>
         <translation>Karte öffnen</translation>
     </message>
     <message>
         <location line="+25"/>
-        <location line="+144"/>
+        <location line="+141"/>
         <source>Error Saving Map</source>
         <translation>Fehler beim speichern der Karte</translation>
     </message>
@@ -1077,12 +1312,17 @@ Zeile %1, Spalte %2</translation>
         <translation>Der gegebende Dateiname hat keine bekannte Dateierweiterung.</translation>
     </message>
     <message>
-        <location line="+47"/>
+        <location line="+41"/>
         <source>Cut</source>
         <translation>Ausschneiden</translation>
     </message>
     <message>
-        <location line="+97"/>
+        <location line="+80"/>
+        <source>Paste Objects</source>
+        <translation>Objekte einfügen</translation>
+    </message>
+    <message>
+        <location line="+79"/>
         <source>Add External Tileset</source>
         <translation>Externes Tileset hinzufügen</translation>
     </message>
@@ -1107,12 +1347,12 @@ Zeile %1, Spalte %2</translation>
         <translation>Automatisches Mapping</translation>
     </message>
     <message>
-        <location line="+212"/>
+        <location line="+223"/>
         <source>[*]%1 - Tiled</source>
         <translation>[*]%1 - Tiled</translation>
     </message>
     <message>
-        <location line="-89"/>
+        <location line="-103"/>
         <source>%1%</source>
         <translation>%1%</translation>
     </message>
@@ -1120,17 +1360,17 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::MapDocument</name>
     <message>
-        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
+        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
         <source>untitled.tmx</source>
         <translation>unbenannt.tmx</translation>
     </message>
     <message>
-        <location line="+39"/>
+        <location line="+44"/>
         <source>Resize Map</source>
         <translation>Kartengröße ändern</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="+23"/>
         <source>Offset Map</source>
         <translation>Verschiebe Karte</translation>
     </message>
@@ -1145,7 +1385,7 @@ Zeile %1, Spalte %2</translation>
         <translation>Objektebene %1</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+22"/>
         <source>Copy of %1</source>
         <translation>Kopie von %1</translation>
     </message>
@@ -1155,7 +1395,12 @@ Zeile %1, Spalte %2</translation>
         <translation>Ebene duplizieren</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+24"/>
+        <source>Merge Layer Down</source>
+        <translation>Ebene nach unten vereinigen</translation>
+    </message>
+    <message>
+        <location line="+138"/>
         <source>Tile</source>
         <translation>Kachel</translation>
     </message>
@@ -1168,27 +1413,42 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::MapDocumentActionHandler</name>
     <message>
-        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+45"/>
+        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+46"/>
         <source>Ctrl+Shift+A</source>
-        <translation>Strg+Shift+A</translation>
+        <translation></translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+8"/>
         <source>Ctrl+Shift+D</source>
-        <translation>Strg+Shift+D</translation>
+        <translation></translation>
     </message>
     <message>
-        <location line="+9"/>
+        <location line="+11"/>
+        <source>PgUp</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>PgDown</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+3"/>
         <source>Ctrl+Shift+Up</source>
-        <translation>Ctrl+Shift+Up</translation>
+        <translation></translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Ctrl+Shift+Down</source>
-        <translation>Ctrl+Shift+Down</translation>
+        <translation></translation>
     </message>
     <message>
-        <location line="+35"/>
+        <location line="+5"/>
+        <source>Ctrl+Shift+H</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+45"/>
         <source>Select &amp;All</source>
         <translation>Selektiere &amp;alles</translation>
     </message>
@@ -1199,19 +1459,37 @@ Zeile %1, Spalte %2</translation>
     </message>
     <message>
         <location line="+2"/>
-        <source>Add &amp;Tile Layer...</source>
-        <translation>&amp;Kachelebene hinzufügen...</translation>
+        <source>&amp;Crop to Selection</source>
+        <translation>Selektion &amp;ausschneiden</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Add &amp;Tile Layer</source>
+        <translation>&amp;Kachelebene hinzufügen</translation>
     </message>
     <message>
         <location line="+1"/>
+        <source>Add &amp;Object Layer</source>
+        <translation>&amp;Objektebene hinzufügen</translation>
+    </message>
+    <message>
+        <source>Add &amp;Tile Layer...</source>
+        <translation type="obsolete">&amp;Kachelebene hinzufügen...</translation>
+    </message>
+    <message>
         <source>Add &amp;Object Layer...</source>
-        <translation>&amp;Objektebene hinzufügen...</translation>
+        <translation type="obsolete">&amp;Objektebene hinzufügen...</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>&amp;Duplicate Layer</source>
         <translation>Ebene &amp;duplizieren</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>&amp;Merge Layer Down</source>
+        <translation>&amp;Ebene nach unten vereinigen</translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>&amp;Remove Layer</source>
@@ -1219,13 +1497,36 @@ Zeile %1, Spalte %2</translation>
     </message>
     <message>
         <location line="+1"/>
-        <source>Move Layer &amp;Up</source>
-        <translation>Ebene a&amp;nheben</translation>
+        <source>Select Pre&amp;vious Layer</source>
+        <translation>Wähle &amp;vorherige Ebene aus</translation>
     </message>
     <message>
         <location line="+1"/>
+        <source>Select &amp;Next Layer</source>
+        <translation>Wähle &amp;nächste Ebene aus</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>R&amp;aise Layer</source>
+        <translation>Ebene &amp;anheben</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>&amp;Lower Layer</source>
+        <translation>Ebene ab&amp;senken</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Show/&amp;Hide all Other Layers</source>
+        <translation>Zeige/&amp;Verstecke alle anderen Ebenen</translation>
+    </message>
+    <message>
+        <source>Move Layer &amp;Up</source>
+        <translation type="obsolete">Ebene a&amp;nheben</translation>
+    </message>
+    <message>
         <source>Move Layer Dow&amp;n</source>
-        <translation>Ebene a&amp;bsenken</translation>
+        <translation type="obsolete">Ebene a&amp;bsenken</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1286,7 +1587,7 @@ Zeile %1, Spalte %2</translation>
         <translation>Objekt</translation>
     </message>
     <message>
-        <location line="+47"/>
+        <location line="+52"/>
         <source>Change Object</source>
         <translation>Objekt ändern</translation>
     </message>
@@ -1294,51 +1595,44 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::ObjectSelectionTool</name>
     <message>
-        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
-        <location line="+135"/>
+        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
+        <location line="+110"/>
         <source>Select Objects</source>
         <translation>Objekte auswählen</translation>
     </message>
     <message>
-        <location line="-132"/>
-        <location line="+133"/>
+        <location line="-108"/>
+        <location line="+109"/>
         <source>S</source>
         <translation>S</translation>
     </message>
     <message>
-        <location line="+97"/>
         <source>Object &amp;Properties...</source>
-        <translation>Objekt&amp;eigenschaften...</translation>
+        <translation type="obsolete">Objekt&amp;eigenschaften...</translation>
     </message>
     <message numerus="yes">
-        <location line="-20"/>
-        <location line="+145"/>
         <source>Duplicate %n Object(s)</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Dupliziere Objekt</numerusform>
             <numerusform>Dupliziere %n Objekte</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-144"/>
-        <location line="+162"/>
         <source>Remove %n Object(s)</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Entferne Objekt</numerusform>
             <numerusform>Entferne %n Objekte</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-153"/>
-        <location line="+163"/>
         <source>Move %n Object(s) to Layer</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Verschiebe Objekt zu anderer Ebene</numerusform>
             <numerusform>Verschiebe %n Objekte zu anderer Ebene</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-46"/>
+        <location line="+117"/>
         <source>Move %n Object(s)</source>
         <translation>
             <numerusform>Verschiebe Objekt</numerusform>
@@ -1358,7 +1652,7 @@ Zeile %1, Spalte %2</translation>
 <context>
     <name>Tiled::Internal::PropertiesDialog</name>
     <message>
-        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
+        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
         <source>%1 Properties</source>
         <translation>%1eigenschaften</translation>
     </message>
@@ -1400,7 +1694,7 @@ Do you want to replace it?</source>
         <translation>Die Datei %1 existiert bereits. Soll sie ersetzt werden?</translation>
     </message>
     <message>
-        <location line="+71"/>
+        <location line="+73"/>
         <source>Image</source>
         <translation>Bild</translation>
     </message>
@@ -1429,13 +1723,13 @@ Do you want to replace it?</source>
     <name>Tiled::Internal::StampBrush</name>
     <message>
         <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
-        <location line="+279"/>
+        <location line="+281"/>
         <source>Stamp Brush</source>
         <translation>Stempel</translation>
     </message>
     <message>
-        <location line="-276"/>
-        <location line="+277"/>
+        <location line="-278"/>
+        <location line="+279"/>
         <source>B</source>
         <translation>B</translation>
     </message>
@@ -1443,7 +1737,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetDock</name>
     <message>
-        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
+        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
         <source>Remove Tileset</source>
         <translation>Tileset entfernen</translation>
     </message>
@@ -1458,7 +1752,7 @@ Do you want to replace it?</source>
         <translation>Soll dieses Tileset sowie alle Referenzen auf dieses entfernt werden?</translation>
     </message>
     <message>
-        <location line="+58"/>
+        <location line="+64"/>
         <source>Tilesets</source>
         <translation>Tilesets</translation>
     </message>
@@ -1466,7 +1760,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetView</name>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
         <source>Tile &amp;Properties...</source>
         <translation>Kachel&amp;eigenschaften...</translation>
     </message>
@@ -1481,7 +1775,12 @@ Do you want to replace it?</source>
         <translation>&amp;Importiere Tileset</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+12"/>
+        <source>Show &amp;Grid</source>
+        <translation>Zeige &amp;Raster</translation>
+    </message>
+    <message>
+        <location line="+16"/>
         <source>Tile</source>
         <translation>Kachel</translation>
     </message>
@@ -1552,7 +1851,7 @@ Do you want to replace it?</source>
 <context>
     <name>TmxViewer</name>
     <message>
-        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
+        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
         <source>TMX Viewer</source>
         <translation>TMX-Betrachter</translation>
     </message>
@@ -1570,12 +1869,12 @@ Do you want to replace it?</source>
         <translation>Ebene löschen</translation>
     </message>
     <message>
-        <location filename="../src/tiled/addremovemapobject.cpp" line="+76"/>
+        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
         <source>Add Object</source>
         <translation>Objekt hinzufügen</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+13"/>
         <source>Remove Object</source>
         <translation>Objekt löschen</translation>
     </message>
@@ -1606,7 +1905,7 @@ Do you want to replace it?</source>
         <translation>Eigenschaften %1 ändern</translation>
     </message>
     <message>
-        <location filename="../src/tiled/changeselection.cpp" line="+31"/>
+        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
         <source>Change Selection</source>
         <translation>Selektion ändern</translation>
     </message>
@@ -1621,14 +1920,12 @@ Do you want to replace it?</source>
         <translation>Bereich füllen</translation>
     </message>
     <message>
-        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
         <source>Move Layer Down</source>
-        <translation>Ebene absenken</translation>
+        <translation type="obsolete">Ebene absenken</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Move Layer Up</source>
-        <translation>Ebene anheben</translation>
+        <translation type="obsolete">Ebene anheben</translation>
     </message>
     <message>
         <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
@@ -1676,7 +1973,7 @@ Do you want to replace it?</source>
         <translation>Objektgröße ändern</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
         <source>Import Tileset</source>
         <translation>Tileset importieren</translation>
     </message>
@@ -1685,6 +1982,22 @@ Do you want to replace it?</source>
         <source>Export Tileset</source>
         <translation>Tileset exportieren</translation>
     </message>
+    <message>
+        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
+        <source>Lower Layer</source>
+        <translation>Niedrigere Ebene</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Raise Layer</source>
+        <translation>Höhere Ebene</translation>
+    </message>
+    <message>
+        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
+        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
+        <source>Change Image Layer Properties</source>
+        <translation>Bildebenen Eigenschaften ändern</translation>
+    </message>
 </context>
 <context>
     <name>Utils</name>
