@@ -35,9 +35,54 @@
         <translation>Propiedades</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+24"/>
+        <source>&amp;Save map before executing</source>
+        <translation>&amp;Guardar mapa antes de ejecutarlo</translation>
+    </message>
+    <message>
         <source>Save map before executing</source>
-        <translation>Guardar el mapa antes de ejecutarlo</translation>
+        <translation type="obsolete">Guardar el mapa antes de ejecutarlo</translation>
+    </message>
+</context>
+<context>
+    <name>Droidcraft::DroidcraftPlugin</name>
+    <message>
+        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
+        <source>This is not a valid Droidcraft map file!</source>
+        <translation>¡Este no es un tipo de fichero de mapa Droidcraft válido!</translation>
+    </message>
+    <message>
+        <location line="+44"/>
+        <source>The map needs to have exactly one tile layer!</source>
+        <translation>¡El mapa necesita tener exactamente una sola capa de patrones!</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>The layer must have a size of 48 x 48 tiles!</source>
+        <translation>¡La capa debe tener un tamaño de 48x48 patrones!</translation>
+    </message>
+    <message>
+        <location line="+22"/>
+        <source>Could not open file for writing.</source>
+        <translation>No se pudo abrir el archivo para escritura.</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Droidcraft map files (*.dat)</source>
+        <translation>Ficheros de mapa Droidcraft (*.dat)</translation>
+    </message>
+</context>
+<context>
+    <name>Lua::LuaPlugin</name>
+    <message>
+        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
+        <source>Could not open file for writing.</source>
+        <translation>No se pudo abrir el archivo para escritura.</translation>
+    </message>
+    <message>
+        <location line="+16"/>
+        <source>Lua files (*.lua)</source>
+        <translation>Ficheros Lua (*.lua)</translation>
     </message>
 </context>
 <context>
@@ -157,7 +202,12 @@
         <translation>&amp;Nuevo...</translation>
     </message>
     <message>
-        <location line="+98"/>
+        <location line="+56"/>
+        <source>Save As &amp;Image...</source>
+        <translation>Guardar &amp;Imagen como...</translation>
+    </message>
+    <message>
+        <location line="+42"/>
         <source>&amp;Export As...</source>
         <translation>&amp;Exportar como...</translation>
     </message>
@@ -269,12 +319,11 @@
         <translation>Ctrl+0</translation>
     </message>
     <message>
-        <location line="+5"/>
         <source>Save As Image...</source>
-        <translation>Guardar como Imagen...</translation>
+        <translation type="obsolete">Guardar como Imagen...</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+17"/>
         <source>Cu&amp;t</source>
         <translation>Cor&amp;tar</translation>
     </message>
@@ -329,7 +378,7 @@
 <context>
     <name>MapReader</name>
     <message>
-        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
+        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
         <source>Not a map file.</source>
         <translation>No es un archivo de Mapas.</translation>
     </message>
@@ -358,7 +407,7 @@ Línea %1, columna %2</translation>
         <translation>Incapaz de leer archivo: %1</translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+44"/>
         <source>Unsupported map orientation: &quot;%1&quot;</source>
         <translation>Orientación del Mapa no soportada: &quot;%1&quot;</translation>
     </message>
@@ -391,19 +440,19 @@ Línea %1, columna %2</translation>
     </message>
     <message>
         <location line="+11"/>
-        <location line="+66"/>
+        <location line="+72"/>
         <location line="+39"/>
-        <location line="+103"/>
+        <location line="+90"/>
         <source>Invalid tile: %1</source>
         <translation>Patrón no válido: %1</translation>
     </message>
     <message>
-        <location line="-188"/>
+        <location line="-181"/>
         <source>Unknown encoding: %1</source>
         <translation>Codificación desconocida: %1</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+25"/>
         <source>Compression method &apos;%1&apos; not supported</source>
         <translation>Método de compresión &apos;%1&apos; no soportado</translation>
     </message>
@@ -419,21 +468,53 @@ Línea %1, columna %2</translation>
         <translation>Incapaz de interpretar patrón en (%1,%2) en la capa &apos;%3&apos;</translation>
     </message>
     <message>
-        <location line="+20"/>
         <source>Invalid global tile id (less than 0): %1</source>
-        <translation>ID global del Patrón no válido (inferior a 0): %1</translation>
+        <translation type="obsolete">ID global del Patrón no válido (inferior a 0): %1</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+20"/>
         <source>Tile used but no tilesets specified</source>
         <translation>Patrón usado, pero no especificado en el conjunto de patrones</translation>
     </message>
     <message>
-        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
+        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
         <source>Could not open file for writing.</source>
         <translation>No se pudo abrir el archivo para escritura.</translation>
     </message>
 </context>
+<context>
+    <name>NewImageLayerDialog</name>
+    <message>
+        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
+        <source>New Tileset</source>
+        <translation>Nuevo conjunto de Patrones</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Image layer</source>
+        <translation>Capa de Imagen</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>&amp;Name:</source>
+        <translation>&amp;Nombre:</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Image:</source>
+        <translation>Imagen:</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>&amp;Browse...</source>
+        <translation>&amp;Explorar...</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Use transparent color:</source>
+        <translation>Usar color transparente:</translation>
+    </message>
+</context>
 <context>
     <name>NewMapDialog</name>
     <message>
@@ -836,6 +917,41 @@ Línea %1, columna %2</translation>
         <translation>Archivos de mapa T-Engine4 (*.lua)</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::AbstractObjectTool</name>
+    <message numerus="yes">
+        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
+        <location line="+54"/>
+        <source>Duplicate %n Object(s)</source>
+        <translation>
+            <numerusform>Duplicar Objeto</numerusform>
+            <numerusform>Duplicar %n Objetos</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-53"/>
+        <location line="+71"/>
+        <source>Remove %n Object(s)</source>
+        <translation>
+            <numerusform>Eliminar Objeto</numerusform>
+            <numerusform>Eliminar %n Objetos</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-62"/>
+        <location line="+72"/>
+        <source>Move %n Object(s) to Layer</source>
+        <translation>
+            <numerusform>Mover Objeto a la Capa</numerusform>
+            <numerusform>Mover %n Objetos a la Capa</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location line="-62"/>
+        <source>Object &amp;Properties...</source>
+        <translation>&amp;Propiedades del Objeto...</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::AutoMapper</name>
     <message>
@@ -844,7 +960,7 @@ Línea %1, columna %2</translation>
         <translation>¡Se encontraron multiples capas %1!</translation>
     </message>
     <message>
-        <location line="+115"/>
+        <location line="+110"/>
         <source>No ruleRegions layer found!</source>
         <translation>¡No se encontraron capas ruleRegions!</translation>
     </message>
@@ -859,7 +975,7 @@ Línea %1, columna %2</translation>
         <translation>¡No se encontró la capa ruleSet!</translation>
     </message>
     <message>
-        <location line="+208"/>
+        <location line="+212"/>
         <source>Tile</source>
         <translation>Patrón</translation>
     </message>
@@ -867,12 +983,12 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::AutomaticMappingManager</name>
     <message>
-        <location line="+491"/>
+        <location line="+497"/>
         <source>No set layer found!</source>
         <translation>¡No se encontró un set de capas!</translation>
     </message>
     <message>
-        <location line="+29"/>
+        <location line="+27"/>
         <source>Apply AutoMap rules</source>
         <translation>Aplicar reglas de AutoMapa</translation>
     </message>
@@ -923,7 +1039,7 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::CommandButton</name>
     <message>
-        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
+        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
         <source>Execute Command</source>
         <translation>Ejecutar orden</translation>
     </message>
@@ -933,13 +1049,12 @@ Línea %1, columna %2</translation>
         <translation>F5</translation>
     </message>
     <message>
-        <location line="+39"/>
-        <location line="+61"/>
+        <location line="+24"/>
         <source>Error Executing Command</source>
         <translation>Error ejecutando orden</translation>
     </message>
     <message>
-        <location line="-60"/>
+        <location line="+1"/>
         <source>You do not have any commands setup.</source>
         <translation>Usted no tiene ninguna orden preparada.</translation>
     </message>
@@ -949,25 +1064,24 @@ Línea %1, columna %2</translation>
         <translation>Editar ordenes...</translation>
     </message>
     <message>
-        <location line="+50"/>
+        <location line="+45"/>
         <source>Edit Commands...</source>
         <translation>Editar Ordenes...</translation>
     </message>
     <message>
-        <location line="+9"/>
         <source>There was an error running the command</source>
-        <translation>Hubo un error ejecutando la orden</translation>
+        <translation type="obsolete">Hubo un error ejecutando la orden</translation>
     </message>
 </context>
 <context>
     <name>Tiled::Internal::CommandDataModel</name>
     <message>
-        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
+        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
         <source>Open in text editor</source>
         <translation>Abrir en el editor de texto</translation>
     </message>
     <message>
-        <location line="+90"/>
+        <location line="+92"/>
         <location line="+67"/>
         <source>&lt;new command&gt;</source>
         <translation>&lt;Nueva Orden&gt;</translation>
@@ -993,7 +1107,7 @@ Línea %1, columna %2</translation>
         <translation>Añadir una nueva orden</translation>
     </message>
     <message>
-        <location line="+100"/>
+        <location line="+101"/>
         <source>Name</source>
         <translation>Nombre</translation>
     </message>
@@ -1007,20 +1121,93 @@ Línea %1, columna %2</translation>
         <source>Enable</source>
         <translation>Activar</translation>
     </message>
+    <message>
+        <location line="+14"/>
+        <source>Move Up</source>
+        <translation>Subir</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Move Down</source>
+        <translation>Bajar</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Execute</source>
+        <translation>Ejecutar</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Execute in Terminal</source>
+        <translation>Ejecutar en la Consola</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>Delete</source>
+        <translation>Borrar</translation>
+    </message>
+    <message>
+        <location line="+84"/>
+        <source>%1 (copy)</source>
+        <translation>%1 (copiar)</translation>
+    </message>
+    <message>
+        <location line="+16"/>
+        <source>New command</source>
+        <translation>Nueva orden</translation>
+    </message>
 </context>
 <context>
     <name>Tiled::Internal::CommandDialog</name>
     <message>
-        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
+        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
         <source>Edit Commands</source>
         <translation>Editar Ordenes</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::CommandProcess</name>
+    <message>
+        <location filename="../src/tiled/command.cpp" line="+122"/>
+        <source>Unable to create/open %1</source>
+        <translation>No es posible crear ó abrir %1</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Unable to add executable permissions to %1</source>
+        <translation>No es posible dar permiso de ejecución a %1</translation>
+    </message>
+    <message>
+        <location line="+26"/>
+        <source>The command failed to start.</source>
+        <translation>La orden fue incapaz de iniciarse.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>The command crashed.</source>
+        <translation>La orden se bloqueó.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>The command timed out.</source>
+        <translation>La orden agotó el tiempo.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>An unknown error occurred.</source>
+        <translation>Ocurrió un error desconocido.</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Error Executing %1</source>
+        <translation>Error ejecutando %1</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::CreateObjectTool</name>
     <message>
         <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
-        <location line="+111"/>
+        <location line="+100"/>
         <source>O</source>
         <translation>O</translation>
     </message>
@@ -1055,10 +1242,38 @@ Línea %1, columna %2</translation>
         <translation>G</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
+    <message>
+        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
+        <source>Image Layer</source>
+        <translation>Capa de Imagen</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Browse...</source>
+        <translation>Explorar...</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Image:</source>
+        <translation>Imagen:</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Transparent color:</source>
+        <translation>Color Transparente:</translation>
+    </message>
+    <message>
+        <location line="+17"/>
+        <source>Layer Image</source>
+        <translation>Capa de Imagen</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::LayerDock</name>
     <message>
-        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
+        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
         <source>Layers</source>
         <translation>Capas</translation>
     </message>
@@ -1090,14 +1305,14 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::MainWindow</name>
     <message>
-        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
-        <location line="+10"/>
+        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
+        <location line="+8"/>
         <source>Undo</source>
         <translation>Deshacer</translation>
     </message>
     <message>
-        <location line="-9"/>
-        <location line="+8"/>
+        <location line="-7"/>
+        <location line="+6"/>
         <source>Redo</source>
         <translation>Rehacer</translation>
     </message>
@@ -1106,13 +1321,13 @@ Línea %1, columna %2</translation>
         <translation type="obsolete">Error en la apertura del mapa</translation>
     </message>
     <message>
-        <location line="+391"/>
+        <location line="+418"/>
         <source>Open Map</source>
         <translation>Abrir Mapa</translation>
     </message>
     <message>
         <location line="-13"/>
-        <location line="+79"/>
+        <location line="+76"/>
         <source>Tiled map files (*.tmx)</source>
         <translation>Archivos de mapas de Tiled (*.tmx)</translation>
     </message>
@@ -1121,7 +1336,7 @@ Línea %1, columna %2</translation>
         <translation type="obsolete">Error en la grabación del mapa</translation>
     </message>
     <message>
-        <location line="-425"/>
+        <location line="-451"/>
         <source>Ctrl+=</source>
         <translation>Ctrl+=</translation>
     </message>
@@ -1136,25 +1351,45 @@ Línea %1, columna %2</translation>
         <translation>-</translation>
     </message>
     <message>
-        <location line="+19"/>
-        <location line="+962"/>
+        <location line="+22"/>
+        <location line="+1047"/>
         <source>&amp;Layer</source>
         <translation>&amp;Capa</translation>
     </message>
     <message>
-        <location line="-711"/>
+        <location line="-910"/>
+        <source>Ctrl+PgUp</source>
+        <translation>Ctrl+PgUp</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Ctrl+PgDown</source>
+        <translation>Ctrl+PgDown</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
+    <message>
+        <location line="+127"/>
         <source>Error Opening Map</source>
         <translation>Error Abriendo Mapa</translation>
     </message>
     <message>
-        <location line="+69"/>
-        <location line="+138"/>
+        <location line="+73"/>
+        <location line="+135"/>
         <source>All Files (*)</source>
         <translation>Todos los ficheros (*)</translation>
     </message>
     <message>
-        <location line="-97"/>
-        <location line="+144"/>
+        <location line="-94"/>
+        <location line="+141"/>
         <source>Error Saving Map</source>
         <translation>Error Guardando Mapa</translation>
     </message>
@@ -1189,12 +1424,17 @@ Línea %1, columna %2</translation>
         <translation>El nombre de fichero dado tiene una extensión desconocida.</translation>
     </message>
     <message>
-        <location line="+47"/>
+        <location line="+41"/>
         <source>Cut</source>
         <translation>Cortar</translation>
     </message>
     <message>
-        <location line="+377"/>
+        <location line="+80"/>
+        <source>Paste Objects</source>
+        <translation>Pegar Objetos</translation>
+    </message>
+    <message>
+        <location line="+370"/>
         <source>[*]%1 - Tiled</source>
         <translation>[*]%1 - Tiled</translation>
     </message>
@@ -1203,7 +1443,7 @@ Línea %1, columna %2</translation>
         <translation type="obsolete">Añadir conjunto de Patrones</translation>
     </message>
     <message>
-        <location line="-280"/>
+        <location line="-291"/>
         <source>Add External Tileset</source>
         <translation>Añadir conjunto de Patrones Externo</translation>
     </message>
@@ -1228,7 +1468,7 @@ Línea %1, columna %2</translation>
         <translation>Mapeado Automático</translation>
     </message>
     <message>
-        <location line="+123"/>
+        <location line="+120"/>
         <source>%1%</source>
         <translation>%1%</translation>
     </message>
@@ -1260,17 +1500,17 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::MapDocument</name>
     <message>
-        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
+        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
         <source>untitled.tmx</source>
         <translation>untitled.tmx</translation>
     </message>
     <message>
-        <location line="+39"/>
+        <location line="+44"/>
         <source>Resize Map</source>
         <translation>Redimensionar Mapa</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="+23"/>
         <source>Offset Map</source>
         <translation>Desplazar Mapa</translation>
     </message>
@@ -1285,7 +1525,7 @@ Línea %1, columna %2</translation>
         <translation>Capa de Objetos %1</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+22"/>
         <source>Copy of %1</source>
         <translation>Copiar desde %1</translation>
     </message>
@@ -1295,7 +1535,12 @@ Línea %1, columna %2</translation>
         <translation>Duplicar Capa</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+24"/>
+        <source>Merge Layer Down</source>
+        <translation>Mezclar capa hacía abajo</translation>
+    </message>
+    <message>
+        <location line="+138"/>
         <source>Tile</source>
         <translation>Patrón</translation>
     </message>
@@ -1308,7 +1553,7 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::MapDocumentActionHandler</name>
     <message>
-        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+100"/>
+        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
         <source>Select &amp;All</source>
         <translation>Seleccionar &amp;Todo</translation>
     </message>
@@ -1318,57 +1563,113 @@ Línea %1, columna %2</translation>
         <translation>Seleccionar &amp;Nada</translation>
     </message>
     <message>
-        <location line="-56"/>
+        <location line="-81"/>
         <source>Ctrl+Shift+A</source>
         <translation>Ctrl+Shift+A</translation>
     </message>
     <message>
-        <location line="+58"/>
         <source>Add &amp;Tile Layer...</source>
-        <translation>Añadir Capa de &amp;Patrones...</translation>
+        <translation type="obsolete">Añadir Capa de &amp;Patrones...</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Add &amp;Object Layer...</source>
-        <translation>Añadir Capa de &amp;Objetos...</translation>
+        <translation type="obsolete">Añadir Capa de &amp;Objetos...</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+87"/>
         <source>&amp;Duplicate Layer</source>
         <translation>&amp;Duplicar Capa</translation>
     </message>
     <message>
-        <location line="-54"/>
+        <location line="-79"/>
         <source>Ctrl+Shift+D</source>
         <translation>Ctrl+Shift+D</translation>
     </message>
     <message>
-        <location line="+55"/>
+        <location line="+11"/>
+        <source>PgUp</source>
+        <translation>PgUp</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>PgDown</source>
+        <translation>PgDown</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Ctrl+Shift+H</source>
+        <translation>Ctrl+Shift+H</translation>
+    </message>
+    <message>
+        <location line="+48"/>
+        <source>&amp;Crop to Selection</source>
+        <translation>&amp;Recortar la Selección</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Add &amp;Tile Layer</source>
+        <translation>Añadir Capa de &amp;Patrones</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Add &amp;Object Layer</source>
+        <translation>Añadir Capa de &amp;Objetos</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>&amp;Merge Layer Down</source>
+        <translation>&amp;Mezclar Capas hacía Abajo</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>&amp;Remove Layer</source>
         <translation>&amp;Eliminar Capa</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Move Layer &amp;Up</source>
-        <translation>&amp;Subir Capa</translation>
+        <translation type="obsolete">&amp;Subir Capa</translation>
     </message>
     <message>
-        <location line="-47"/>
+        <location line="-64"/>
         <source>Ctrl+Shift+Up</source>
         <translation>Ctrl+Shift+Up</translation>
     </message>
     <message>
-        <location line="+48"/>
         <source>Move Layer Dow&amp;n</source>
-        <translation>&amp;Bajar Capa</translation>
+        <translation type="obsolete">&amp;Bajar Capa</translation>
     </message>
     <message>
-        <location line="-43"/>
+        <location line="+5"/>
         <source>Ctrl+Shift+Down</source>
         <translation>Ctrl+Shift+Down</translation>
     </message>
     <message>
-        <location line="+44"/>
+        <location line="+60"/>
+        <source>Select Pre&amp;vious Layer</source>
+        <translation>Seleccionar la Capa Pre&amp;via</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Select &amp;Next Layer</source>
+        <translation>Seleccionar la &amp;Próxima Capa</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>R&amp;aise Layer</source>
+        <translation>S&amp;ubir Capa</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>&amp;Lower Layer</source>
+        <translation>&amp;Bajar Capa</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Show/&amp;Hide all Other Layers</source>
+        <translation>Mostrar/&amp;Ocultar el Resto de Capas</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Layer &amp;Properties...</source>
         <translation>&amp;Propiedades de la Capa...</translation>
     </message>
@@ -1438,7 +1739,7 @@ Línea %1, columna %2</translation>
         <translation type="obsolete">Tipo:</translation>
     </message>
     <message>
-        <location line="+47"/>
+        <location line="+52"/>
         <source>Change Object</source>
         <translation>Modificar Objeto</translation>
     </message>
@@ -1446,51 +1747,44 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::ObjectSelectionTool</name>
     <message>
-        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
-        <location line="+135"/>
+        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
+        <location line="+110"/>
         <source>Select Objects</source>
         <translation>Seleccionar Objetos</translation>
     </message>
     <message>
-        <location line="-132"/>
-        <location line="+133"/>
+        <location line="-108"/>
+        <location line="+109"/>
         <source>S</source>
         <translation>S</translation>
     </message>
     <message numerus="yes">
-        <location line="+77"/>
-        <location line="+145"/>
         <source>Duplicate %n Object(s)</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Duplicar Objeto</numerusform>
             <numerusform>Duplicar %n Objetos</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-144"/>
-        <location line="+162"/>
         <source>Remove %n Object(s)</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Eliminar Objeto</numerusform>
             <numerusform>Eliminar %n Objetos</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-153"/>
-        <location line="+163"/>
         <source>Move %n Object(s) to Layer</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Mover Objeto a la Capa</numerusform>
             <numerusform>Mover %n Objetos a la Capa</numerusform>
         </translation>
     </message>
     <message>
-        <location line="-153"/>
         <source>Object &amp;Properties...</source>
-        <translation>&amp;Propiedades del Objeto...</translation>
+        <translation type="obsolete">&amp;Propiedades del Objeto...</translation>
     </message>
     <message numerus="yes">
-        <location line="+107"/>
+        <location line="+117"/>
         <source>Move %n Object(s)</source>
         <translation>
             <numerusform>Mover Objeto</numerusform>
@@ -1510,7 +1804,7 @@ Línea %1, columna %2</translation>
 <context>
     <name>Tiled::Internal::PropertiesDialog</name>
     <message>
-        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
+        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
         <source>%1 Properties</source>
         <translation>%1 Propiedades</translation>
     </message>
@@ -1553,7 +1847,7 @@ Do you want to replace it?</source>
 ¿Quiere reemplazarla?</translation>
     </message>
     <message>
-        <location line="+71"/>
+        <location line="+73"/>
         <source>Image</source>
         <translation>Imagen</translation>
     </message>
@@ -1582,13 +1876,13 @@ Do you want to replace it?</source>
     <name>Tiled::Internal::StampBrush</name>
     <message>
         <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
-        <location line="+279"/>
+        <location line="+281"/>
         <source>Stamp Brush</source>
         <translation>Brocha de Estampar</translation>
     </message>
     <message>
-        <location line="-276"/>
-        <location line="+277"/>
+        <location line="-278"/>
+        <location line="+279"/>
         <source>B</source>
         <translation>B</translation>
     </message>
@@ -1596,7 +1890,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetDock</name>
     <message>
-        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
+        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
         <source>Remove Tileset</source>
         <translation>Elimina conjunto de Patrones</translation>
     </message>
@@ -1611,7 +1905,7 @@ Do you want to replace it?</source>
         <translation>¿Eliminar este conjunto de patrones y todas las referencias a patrones de dicho conjunto?</translation>
     </message>
     <message>
-        <location line="+58"/>
+        <location line="+64"/>
         <source>Tilesets</source>
         <translation>Conjunto de Patrones</translation>
     </message>
@@ -1623,7 +1917,7 @@ Do you want to replace it?</source>
         <translation type="obsolete">Propiedades...</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
         <source>Tile &amp;Properties...</source>
         <translation>&amp;Propiedades del Patrón...</translation>
     </message>
@@ -1638,7 +1932,12 @@ Do you want to replace it?</source>
         <translation>&amp;Importar conjuntos de Patrones</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+12"/>
+        <source>Show &amp;Grid</source>
+        <translation>Mostrar &amp;Rejilla</translation>
+    </message>
+    <message>
+        <location line="+16"/>
         <source>Tile</source>
         <translation>Patrón</translation>
     </message>
@@ -1810,7 +2109,7 @@ Línea %1, columna %2</translation>
 <context>
     <name>TmxViewer</name>
     <message>
-        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
+        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
         <source>TMX Viewer</source>
         <translation>TMX Viewer</translation>
     </message>
@@ -1828,12 +2127,12 @@ Línea %1, columna %2</translation>
         <translation>Eliminar Capa</translation>
     </message>
     <message>
-        <location filename="../src/tiled/addremovemapobject.cpp" line="+76"/>
+        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
         <source>Add Object</source>
         <translation>Añadir Objeto</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+13"/>
         <source>Remove Object</source>
         <translation>Eliminar Objeto</translation>
     </message>
@@ -1854,7 +2153,7 @@ Línea %1, columna %2</translation>
         <translation>Cambiar %1 Propiedades</translation>
     </message>
     <message>
-        <location filename="../src/tiled/changeselection.cpp" line="+31"/>
+        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
         <source>Change Selection</source>
         <translation>Cambiar Selección</translation>
     </message>
@@ -1869,14 +2168,12 @@ Línea %1, columna %2</translation>
         <translation>Rellenar Área</translation>
     </message>
     <message>
-        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
         <source>Move Layer Down</source>
-        <translation>Bajar Capa</translation>
+        <translation type="obsolete">Bajar Capa</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Move Layer Up</source>
-        <translation>Subir Capa</translation>
+        <translation type="obsolete">Subir Capa</translation>
     </message>
     <message>
         <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
@@ -1929,7 +2226,7 @@ Línea %1, columna %2</translation>
         <translation>Mover conjunto de Patrones</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
         <source>Import Tileset</source>
         <translation>Importar conjunto de Patrones</translation>
     </message>
@@ -1943,6 +2240,22 @@ Línea %1, columna %2</translation>
         <source>Move Object to Layer</source>
         <translation>Mover Objeto a la Capa</translation>
     </message>
+    <message>
+        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
+        <source>Lower Layer</source>
+        <translation>Bajar Capa</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Raise Layer</source>
+        <translation>Subir Capa</translation>
+    </message>
+    <message>
+        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
+        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
+        <source>Change Image Layer Properties</source>
+        <translation>Cambiar las propiedades de la Capa de Imagen</translation>
+    </message>
 </context>
 <context>
     <name>Utils</name>
