@@ -35,9 +35,54 @@
         <translation>Propriétés</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+24"/>
+        <source>&amp;Save map before executing</source>
+        <translation>&amp;Sauvegarder la carte avant d&apos;exécuter</translation>
+    </message>
+    <message>
         <source>Save map before executing</source>
-        <translation>Sauvegarder la carte avant exécution</translation>
+        <translation type="obsolete">Sauvegarder la carte avant exécution</translation>
+    </message>
+</context>
+<context>
+    <name>Droidcraft::DroidcraftPlugin</name>
+    <message>
+        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
+        <source>This is not a valid Droidcraft map file!</source>
+        <translation>Ce fichier n&apos;est pas une carte Droidcraft valide !</translation>
+    </message>
+    <message>
+        <location line="+44"/>
+        <source>The map needs to have exactly one tile layer!</source>
+        <translation>La carte doit avoir exactement un seul calque !</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>The layer must have a size of 48 x 48 tiles!</source>
+        <translation>Les tiles du calque doivent de la taille de de 48 par 48 !</translation>
+    </message>
+    <message>
+        <location line="+22"/>
+        <source>Could not open file for writing.</source>
+        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Droidcraft map files (*.dat)</source>
+        <translation>Cartes Droidcraft (*.dat)</translation>
+    </message>
+</context>
+<context>
+    <name>Lua::LuaPlugin</name>
+    <message>
+        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
+        <source>Could not open file for writing.</source>
+        <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
+    </message>
+    <message>
+        <location line="+16"/>
+        <source>Lua files (*.lua)</source>
+        <translation>Fichier Lua (*.lua)</translation>
     </message>
 </context>
 <context>
@@ -157,7 +202,12 @@
         <translation>&amp;Nouveau...</translation>
     </message>
     <message>
-        <location line="+98"/>
+        <location line="+56"/>
+        <source>Save As &amp;Image...</source>
+        <translation>Sauvegarder en tant qu&apos;&amp;image...</translation>
+    </message>
+    <message>
+        <location line="+42"/>
         <source>&amp;Export As...</source>
         <translation>&amp;Exporter en tant que...</translation>
     </message>
@@ -257,12 +307,11 @@
         <translation>Ctrl+0</translation>
     </message>
     <message>
-        <location line="+5"/>
         <source>Save As Image...</source>
-        <translation>Enregistrer en tant qu&apos;image...</translation>
+        <translation type="obsolete">Enregistrer en tant qu&apos;image...</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+17"/>
         <source>Cu&amp;t</source>
         <translation>&amp;Couper</translation>
     </message>
@@ -317,7 +366,7 @@
 <context>
     <name>MapReader</name>
     <message>
-        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
+        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
         <source>Not a map file.</source>
         <translation>Le fichier ne possède pas un format valide.</translation>
     </message>
@@ -346,7 +395,7 @@ Ligne %1, colonne %2</translation>
         <translation>Impossible de lire le fichier : %1</translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+44"/>
         <source>Unsupported map orientation: &quot;%1&quot;</source>
         <translation>Orientation de carte non supporté : &quot;%1&quot;</translation>
     </message>
@@ -379,19 +428,19 @@ Ligne %1, colonne %2</translation>
     </message>
     <message>
         <location line="+11"/>
-        <location line="+66"/>
+        <location line="+72"/>
         <location line="+39"/>
-        <location line="+103"/>
+        <location line="+90"/>
         <source>Invalid tile: %1</source>
         <translation>Tile invalide : %1</translation>
     </message>
     <message>
-        <location line="-188"/>
+        <location line="-181"/>
         <source>Unknown encoding: %1</source>
         <translation>Encodage inconnu : %1</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+25"/>
         <source>Compression method &apos;%1&apos; not supported</source>
         <translation>Méthode de compression non supportée : &apos;%1&apos;</translation>
     </message>
@@ -407,21 +456,53 @@ Ligne %1, colonne %2</translation>
         <translation>Impossible de lire le tile en position (%1,%2) sur le calque &apos;%3&apos;</translation>
     </message>
     <message>
-        <location line="+20"/>
         <source>Invalid global tile id (less than 0): %1</source>
-        <translation>ID de tile globale invalide (plus petit que 0): %1</translation>
+        <translation type="obsolete">ID de tile globale invalide (plus petit que 0): %1</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+20"/>
         <source>Tile used but no tilesets specified</source>
         <translation>Un tile sans tileset correspondant est utilisé</translation>
     </message>
     <message>
-        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
+        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
         <source>Could not open file for writing.</source>
         <translation>La tentative d&apos;écriture du fichier a échoué.</translation>
     </message>
 </context>
+<context>
+    <name>NewImageLayerDialog</name>
+    <message>
+        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
+        <source>New Tileset</source>
+        <translation>Nouveau Tileset</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Image layer</source>
+        <translation>Calque d&apos;image</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>&amp;Name:</source>
+        <translation>&amp;Nom :</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Image:</source>
+        <translation>Image :</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>&amp;Browse...</source>
+        <translation>&amp;Rechercher...</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Use transparent color:</source>
+        <translation>Utiliser la transparence :</translation>
+    </message>
+</context>
 <context>
     <name>NewMapDialog</name>
     <message>
@@ -824,6 +905,41 @@ Ligne %1, colonne %2</translation>
         <translation>Fichiers de cartes T-Engine4 (*.lua)</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::AbstractObjectTool</name>
+    <message numerus="yes">
+        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
+        <location line="+54"/>
+        <source>Duplicate %n Object(s)</source>
+        <translation>
+            <numerusform>Dupliquer %n objet</numerusform>
+            <numerusform>Dupliquer %n objets</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-53"/>
+        <location line="+71"/>
+        <source>Remove %n Object(s)</source>
+        <translation>
+            <numerusform>Effacer %n objet</numerusform>
+            <numerusform>Effacer %n objets</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-62"/>
+        <location line="+72"/>
+        <source>Move %n Object(s) to Layer</source>
+        <translation>
+            <numerusform>Déplacer %n objet vers le calque</numerusform>
+            <numerusform>Déplacer %n objets vers le calque</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location line="-62"/>
+        <source>Object &amp;Properties...</source>
+        <translation>&amp;Propriétés de l&apos;objet...</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::AutoMapper</name>
     <message>
@@ -832,7 +948,7 @@ Ligne %1, colonne %2</translation>
         <translation>Calques multiples trouvés pour %1 !</translation>
     </message>
     <message>
-        <location line="+115"/>
+        <location line="+110"/>
         <source>No ruleRegions layer found!</source>
         <translation>Le calque &apos;ruleRegions&apos; n&apos;a pas été trouvé !</translation>
     </message>
@@ -847,7 +963,7 @@ Ligne %1, colonne %2</translation>
         <translation>Le calque &apos;ruleSet&apos; n&apos;a pas été trouvé !</translation>
     </message>
     <message>
-        <location line="+208"/>
+        <location line="+212"/>
         <source>Tile</source>
         <translation>Tile (tuile)</translation>
     </message>
@@ -855,12 +971,12 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::AutomaticMappingManager</name>
     <message>
-        <location line="+491"/>
+        <location line="+497"/>
         <source>No set layer found!</source>
         <translation>Le calque &apos;set&apos; n&apos;a pas été trouvé !</translation>
     </message>
     <message>
-        <location line="+29"/>
+        <location line="+27"/>
         <source>Apply AutoMap rules</source>
         <translation>Appliquer les règles AutoMap</translation>
     </message>
@@ -907,7 +1023,7 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::CommandButton</name>
     <message>
-        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
+        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
         <source>Execute Command</source>
         <translation>Exécuter la commande</translation>
     </message>
@@ -917,13 +1033,12 @@ Ligne %1, colonne %2</translation>
         <translation>F5</translation>
     </message>
     <message>
-        <location line="+39"/>
-        <location line="+61"/>
+        <location line="+24"/>
         <source>Error Executing Command</source>
         <translation>Erreur lors de l&apos;exécution de la commande</translation>
     </message>
     <message>
-        <location line="-60"/>
+        <location line="+1"/>
         <source>You do not have any commands setup.</source>
         <translation>Vous n&apos;avez configuré aucune commandes.</translation>
     </message>
@@ -933,25 +1048,24 @@ Ligne %1, colonne %2</translation>
         <translation>Editer les commandes...</translation>
     </message>
     <message>
-        <location line="+50"/>
+        <location line="+45"/>
         <source>Edit Commands...</source>
         <translation>Editer les commandes...</translation>
     </message>
     <message>
-        <location line="+9"/>
         <source>There was an error running the command</source>
-        <translation>Une erreur est survenue lors de l&apos;exécution de la commande</translation>
+        <translation type="obsolete">Une erreur est survenue lors de l&apos;exécution de la commande</translation>
     </message>
 </context>
 <context>
     <name>Tiled::Internal::CommandDataModel</name>
     <message>
-        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
+        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
         <source>Open in text editor</source>
         <translation>Ouvrir dans l&apos;éditeur de texte</translation>
     </message>
     <message>
-        <location line="+90"/>
+        <location line="+92"/>
         <location line="+67"/>
         <source>&lt;new command&gt;</source>
         <translation>&lt;Nouvelle commande&gt;</translation>
@@ -977,7 +1091,7 @@ Ligne %1, colonne %2</translation>
         <translation>Ajouter une nouvelle commande</translation>
     </message>
     <message>
-        <location line="+100"/>
+        <location line="+101"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
@@ -991,20 +1105,93 @@ Ligne %1, colonne %2</translation>
         <source>Enable</source>
         <translation>Activer</translation>
     </message>
+    <message>
+        <location line="+14"/>
+        <source>Move Up</source>
+        <translation>Déplacer vers le haut</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Move Down</source>
+        <translation>Déplacer vers le bas</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Execute</source>
+        <translation>Exécuter</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Execute in Terminal</source>
+        <translation>Exécuter dans une console de commande</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>Delete</source>
+        <translation>Effacer</translation>
+    </message>
+    <message>
+        <location line="+84"/>
+        <source>%1 (copy)</source>
+        <translation>%1 (copie)</translation>
+    </message>
+    <message>
+        <location line="+16"/>
+        <source>New command</source>
+        <translation>Nouvelle commande</translation>
+    </message>
 </context>
 <context>
     <name>Tiled::Internal::CommandDialog</name>
     <message>
-        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
+        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
         <source>Edit Commands</source>
         <translation>Editer les commandes</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::CommandProcess</name>
+    <message>
+        <location filename="../src/tiled/command.cpp" line="+122"/>
+        <source>Unable to create/open %1</source>
+        <translation>Impossible de créer/ouvrir %1</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Unable to add executable permissions to %1</source>
+        <translation>Impossible de rendre %1 exécutable</translation>
+    </message>
+    <message>
+        <location line="+26"/>
+        <source>The command failed to start.</source>
+        <translation>La commande n&apos;a pas démarré.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>The command crashed.</source>
+        <translation>La commande a crashé.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>The command timed out.</source>
+        <translation>La commande s&apos;est stoppée suite à un Time out.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>An unknown error occurred.</source>
+        <translation>Une erreur inconnue s&apos;est produite.</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Error Executing %1</source>
+        <translation>Erreur lors de l&apos;exécution de %1</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::CreateObjectTool</name>
     <message>
         <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
-        <location line="+111"/>
+        <location line="+100"/>
         <source>O</source>
         <translation>O</translation>
     </message>
@@ -1039,10 +1226,38 @@ Ligne %1, colonne %2</translation>
         <translation>E</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
+    <message>
+        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
+        <source>Image Layer</source>
+        <translation>Calque d&apos;image</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Browse...</source>
+        <translation>Rechercher...</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Image:</source>
+        <translation>Image :</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Transparent color:</source>
+        <translation>Couleur transparente :</translation>
+    </message>
+    <message>
+        <location line="+17"/>
+        <source>Layer Image</source>
+        <translation>Image du calque</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::LayerDock</name>
     <message>
-        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
+        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
         <source>Layers</source>
         <translation>Calques</translation>
     </message>
@@ -1074,14 +1289,14 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::MainWindow</name>
     <message>
-        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
-        <location line="+10"/>
+        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
+        <location line="+8"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location line="-9"/>
-        <location line="+8"/>
+        <location line="-7"/>
+        <location line="+6"/>
         <source>Redo</source>
         <translation>Rétablir</translation>
     </message>
@@ -1090,13 +1305,13 @@ Ligne %1, colonne %2</translation>
         <translation type="obsolete">Erreur lors de l&apos;ouverture de la carte</translation>
     </message>
     <message>
-        <location line="+391"/>
+        <location line="+418"/>
         <source>Open Map</source>
         <translation>Ouvrir une carte</translation>
     </message>
     <message>
         <location line="-13"/>
-        <location line="+79"/>
+        <location line="+76"/>
         <source>Tiled map files (*.tmx)</source>
         <translation>Fichiers de cartes au format Tiled (*.tmx)</translation>
     </message>
@@ -1105,7 +1320,7 @@ Ligne %1, colonne %2</translation>
         <translation type="obsolete">Erreur lors de la sauvegarde de la carte</translation>
     </message>
     <message>
-        <location line="-425"/>
+        <location line="-451"/>
         <source>Ctrl+=</source>
         <translation>Ctrl+=</translation>
     </message>
@@ -1120,25 +1335,47 @@ Ligne %1, colonne %2</translation>
         <translation>-</translation>
     </message>
     <message>
-        <location line="+19"/>
-        <location line="+962"/>
+        <location line="+22"/>
+        <location line="+1047"/>
         <source>&amp;Layer</source>
         <translation>&amp;Calques</translation>
     </message>
     <message>
-        <location line="-711"/>
+        <location line="-910"/>
+        <source>Ctrl+PgUp</source>
+        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
+        <translation>Ctrl+PgUp</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Ctrl+PgDown</source>
+        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
+        <translation>Ctrl+PgDown</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
+    <message>
+        <location line="+127"/>
         <source>Error Opening Map</source>
         <translation>Erreur lors de l&apos;ouverture de la carte</translation>
     </message>
     <message>
-        <location line="+69"/>
-        <location line="+138"/>
+        <location line="+73"/>
+        <location line="+135"/>
         <source>All Files (*)</source>
         <translation>Tous les fichiers (*)</translation>
     </message>
     <message>
-        <location line="-97"/>
-        <location line="+144"/>
+        <location line="-94"/>
+        <location line="+141"/>
         <source>Error Saving Map</source>
         <translation>Erreur lors de la sauvegarde de la carte</translation>
     </message>
@@ -1173,12 +1410,17 @@ Ligne %1, colonne %2</translation>
         <translation>Le fichier ne possède aucune extension connue.</translation>
     </message>
     <message>
-        <location line="+47"/>
+        <location line="+41"/>
         <source>Cut</source>
         <translation>Couper</translation>
     </message>
     <message>
-        <location line="+377"/>
+        <location line="+80"/>
+        <source>Paste Objects</source>
+        <translation>Coller les objets</translation>
+    </message>
+    <message>
+        <location line="+370"/>
         <source>[*]%1 - Tiled</source>
         <translation>[*]%1 - Tiled</translation>
     </message>
@@ -1187,7 +1429,7 @@ Ligne %1, colonne %2</translation>
         <translation type="obsolete">Ajouter des tilesets</translation>
     </message>
     <message>
-        <location line="-280"/>
+        <location line="-291"/>
         <source>Add External Tileset</source>
         <translation>Ajouter un tileset externe</translation>
     </message>
@@ -1212,7 +1454,7 @@ Ligne %1, colonne %2</translation>
         <translation>Mapping automatique</translation>
     </message>
     <message>
-        <location line="+123"/>
+        <location line="+120"/>
         <source>%1%</source>
         <translation>%1%</translation>
     </message>
@@ -1244,17 +1486,17 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::MapDocument</name>
     <message>
-        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
+        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
         <source>untitled.tmx</source>
         <translation>sans-titre.tmx</translation>
     </message>
     <message>
-        <location line="+39"/>
+        <location line="+44"/>
         <source>Resize Map</source>
         <translation>Redimensionner la carte</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="+23"/>
         <source>Offset Map</source>
         <translation>Décalage de carte</translation>
     </message>
@@ -1269,7 +1511,7 @@ Ligne %1, colonne %2</translation>
         <translation>Calque d&apos;objets %1</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+22"/>
         <source>Copy of %1</source>
         <translation>Copie de %1</translation>
     </message>
@@ -1279,7 +1521,12 @@ Ligne %1, colonne %2</translation>
         <translation>Dupliquer le calque</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+24"/>
+        <source>Merge Layer Down</source>
+        <translation>Fusionner le calque vers le bas</translation>
+    </message>
+    <message>
+        <location line="+138"/>
         <source>Tile</source>
         <translation>Tile (tuile)</translation>
     </message>
@@ -1292,7 +1539,7 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::MapDocumentActionHandler</name>
     <message>
-        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+100"/>
+        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
         <source>Select &amp;All</source>
         <translation>&amp;Tout sélectionner</translation>
     </message>
@@ -1302,57 +1549,116 @@ Ligne %1, colonne %2</translation>
         <translation>Tout &amp;désélectionner</translation>
     </message>
     <message>
-        <location line="-56"/>
+        <location line="-81"/>
         <source>Ctrl+Shift+A</source>
         <translation></translation>
     </message>
     <message>
-        <location line="+58"/>
         <source>Add &amp;Tile Layer...</source>
-        <translation>&amp;Ajouter un calque...</translation>
+        <translation type="obsolete">&amp;Ajouter un calque...</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Add &amp;Object Layer...</source>
-        <translation>&amp;Calque d&apos;objets...</translation>
+        <translation type="obsolete">&amp;Calque d&apos;objets...</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+87"/>
         <source>&amp;Duplicate Layer</source>
         <translation>&amp;Dupliquer le calque</translation>
     </message>
     <message>
-        <location line="-54"/>
+        <location line="-79"/>
         <source>Ctrl+Shift+D</source>
         <translation></translation>
     </message>
     <message>
-        <location line="+55"/>
+        <location line="+11"/>
+        <source>PgUp</source>
+        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
+        <translation>PgUp</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>PgDown</source>
+        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
+        <translation>PgDown</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Ctrl+Shift+H</source>
+        <translatorcomment>Do not translate shortcuts!!   Ne surtout pas traduire les raccourcis !! Utiliser les mêmes idiomes anglais si le raccourcis devait être changé.</translatorcomment>
+        <translation>Ctrl+Shift+H</translation>
+    </message>
+    <message>
+        <location line="+48"/>
+        <source>&amp;Crop to Selection</source>
+        <translation>&amp;Rogner vers la sélection</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Add &amp;Tile Layer</source>
+        <translation>Ajouter un calque de &amp;tile</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Add &amp;Object Layer</source>
+        <translation>Ajouter un calque d&apos;&amp;objet</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>&amp;Merge Layer Down</source>
+        <translation>&amp;Fusionner le cakque vers le bas</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>&amp;Remove Layer</source>
         <translation>&amp;Supprimer le calque</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Move Layer &amp;Up</source>
-        <translation>&amp;Monter le calque courant</translation>
+        <translation type="obsolete">&amp;Monter le calque courant</translation>
     </message>
     <message>
-        <location line="-47"/>
+        <location line="-64"/>
         <source>Ctrl+Shift+Up</source>
         <translation></translation>
     </message>
     <message>
-        <location line="+48"/>
         <source>Move Layer Dow&amp;n</source>
-        <translation>&amp;Descendre le calque courant</translation>
+        <translation type="obsolete">&amp;Descendre le calque courant</translation>
     </message>
     <message>
-        <location line="-43"/>
+        <location line="+5"/>
         <source>Ctrl+Shift+Down</source>
         <translation></translation>
     </message>
     <message>
-        <location line="+44"/>
+        <location line="+60"/>
+        <source>Select Pre&amp;vious Layer</source>
+        <translation>Sélectionner le calque préce&amp;dent</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Select &amp;Next Layer</source>
+        <translation>Sélectionner le calque sui&amp;vant</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>R&amp;aise Layer</source>
+        <translation>M&amp;onter le calque</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>&amp;Lower Layer</source>
+        <translation>Des&amp;cendre le calque</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Show/&amp;Hide all Other Layers</source>
+        <translation>Montrer/Cac&amp;her tous les autres calques</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Layer &amp;Properties...</source>
         <translation>&amp;Propriétés du calque...</translation>
     </message>
@@ -1422,7 +1728,7 @@ Ligne %1, colonne %2</translation>
         <translation type="obsolete">Type :</translation>
     </message>
     <message>
-        <location line="+47"/>
+        <location line="+52"/>
         <source>Change Object</source>
         <translation>Changer d&apos;objet</translation>
     </message>
@@ -1430,51 +1736,44 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::ObjectSelectionTool</name>
     <message>
-        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
-        <location line="+135"/>
+        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
+        <location line="+110"/>
         <source>Select Objects</source>
         <translation>Sélectionner les objets</translation>
     </message>
     <message>
-        <location line="-132"/>
-        <location line="+133"/>
+        <location line="-108"/>
+        <location line="+109"/>
         <source>S</source>
         <translation>S</translation>
     </message>
     <message numerus="yes">
-        <location line="+77"/>
-        <location line="+145"/>
         <source>Duplicate %n Object(s)</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Dupliquer %n objet</numerusform>
             <numerusform>Dupliquer %n objets</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-144"/>
-        <location line="+162"/>
         <source>Remove %n Object(s)</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Effacer %n objet</numerusform>
             <numerusform>Effacer %n objets</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location line="-153"/>
-        <location line="+163"/>
         <source>Move %n Object(s) to Layer</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Déplacer %n objet vers le calque</numerusform>
             <numerusform>Déplacer %n objets vers le calque</numerusform>
         </translation>
     </message>
     <message>
-        <location line="-153"/>
         <source>Object &amp;Properties...</source>
-        <translation>&amp;Propriétés de l&apos;objet...</translation>
+        <translation type="obsolete">&amp;Propriétés de l&apos;objet...</translation>
     </message>
     <message numerus="yes">
-        <location line="+107"/>
+        <location line="+117"/>
         <source>Move %n Object(s)</source>
         <translation>
             <numerusform>Déplacer %n objet</numerusform>
@@ -1494,7 +1793,7 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>Tiled::Internal::PropertiesDialog</name>
     <message>
-        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
+        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
         <source>%1 Properties</source>
         <translation>Propriétés de %1</translation>
     </message>
@@ -1536,7 +1835,7 @@ Do you want to replace it?</source>
         <translation>Le fichier %1 existe déjà. Voulez-vous le remplacer ?</translation>
     </message>
     <message>
-        <location line="+71"/>
+        <location line="+73"/>
         <source>Image</source>
         <translation>Image</translation>
     </message>
@@ -1565,13 +1864,13 @@ Do you want to replace it?</source>
     <name>Tiled::Internal::StampBrush</name>
     <message>
         <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
-        <location line="+279"/>
+        <location line="+281"/>
         <source>Stamp Brush</source>
         <translation>Tampon</translation>
     </message>
     <message>
-        <location line="-276"/>
-        <location line="+277"/>
+        <location line="-278"/>
+        <location line="+279"/>
         <source>B</source>
         <translation>B</translation>
     </message>
@@ -1579,7 +1878,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetDock</name>
     <message>
-        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
+        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
         <source>Remove Tileset</source>
         <translation>Effacer le tileset</translation>
     </message>
@@ -1594,7 +1893,7 @@ Do you want to replace it?</source>
         <translation>Retirer ce tileset et toutes les références aux tiles dans ce tileset ?</translation>
     </message>
     <message>
-        <location line="+58"/>
+        <location line="+64"/>
         <source>Tilesets</source>
         <translation>Tilesets</translation>
     </message>
@@ -1606,7 +1905,7 @@ Do you want to replace it?</source>
         <translation type="obsolete">Propriétés...</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
         <source>Tile &amp;Properties...</source>
         <translation>&amp;Propriétés des tiles...</translation>
     </message>
@@ -1621,7 +1920,12 @@ Do you want to replace it?</source>
         <translation>&amp;Importer le tileset</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+12"/>
+        <source>Show &amp;Grid</source>
+        <translation>Afficher la &amp;grille</translation>
+    </message>
+    <message>
+        <location line="+16"/>
         <source>Tile</source>
         <translation>Tile (tuile)</translation>
     </message>
@@ -1781,7 +2085,7 @@ Ligne %1, colonne %2</translation>
 <context>
     <name>TmxViewer</name>
     <message>
-        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
+        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
         <source>TMX Viewer</source>
         <translation>Visionneuse de fichier TMX</translation>
     </message>
@@ -1799,12 +2103,12 @@ Ligne %1, colonne %2</translation>
         <translation>Supprimer un calque</translation>
     </message>
     <message>
-        <location filename="../src/tiled/addremovemapobject.cpp" line="+76"/>
+        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
         <source>Add Object</source>
         <translation>Ajouter un objet</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+13"/>
         <source>Remove Object</source>
         <translation>Supprimer un objet</translation>
     </message>
@@ -1825,7 +2129,7 @@ Ligne %1, colonne %2</translation>
         <translation>Modifier les propriétés de %1</translation>
     </message>
     <message>
-        <location filename="../src/tiled/changeselection.cpp" line="+31"/>
+        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
         <source>Change Selection</source>
         <translation>Modifier la sélection</translation>
     </message>
@@ -1840,14 +2144,12 @@ Ligne %1, colonne %2</translation>
         <translation>Remplire la zone</translation>
     </message>
     <message>
-        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
         <source>Move Layer Down</source>
-        <translation>Descendre le calque</translation>
+        <translation type="obsolete">Descendre le calque</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Move Layer Up</source>
-        <translation>Monter le calque</translation>
+        <translation type="obsolete">Monter le calque</translation>
     </message>
     <message>
         <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
@@ -1900,7 +2202,7 @@ Ligne %1, colonne %2</translation>
         <translation>Déplacer un tileset</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
         <source>Import Tileset</source>
         <translation>Importer un tileset</translation>
     </message>
@@ -1914,6 +2216,22 @@ Ligne %1, colonne %2</translation>
         <source>Move Object to Layer</source>
         <translation>Déplacer l&apos;objet vers le calque</translation>
     </message>
+    <message>
+        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
+        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
+        <source>Change Image Layer Properties</source>
+        <translation>Modifier les propriétés du calque d&apos;image</translation>
+    </message>
+    <message>
+        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
+        <source>Lower Layer</source>
+        <translation>Descendre le calque</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Raise Layer</source>
+        <translation>Monter le calque</translation>
+    </message>
 </context>
 <context>
     <name>Utils</name>
